"""
    HCL AppScan on Cloud (v2)

    This API allows you to interact with the service. The API allows you to perform many of the operations available in the UI and more.</br>For authentication, use the relevant APIs in the Account section. A successful authentication response includes a bearer token for use in subsequent API calls. Pasting this token in the 'Access token' field above will automatically add the authorization header to any API call that requires a valid session.

    OpenAPI spec version: v2

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

from pyasoc.configuration import Configuration


class UserSiteCommonModelsNewRoleModel:
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "name": "str",
        "is_default": "bool",
        "external_group_name": "str",
        "description": "str",
        "capabilities": "dict(str, bool)",
    }

    attribute_map = {
        "name": "Name",
        "is_default": "IsDefault",
        "external_group_name": "ExternalGroupName",
        "description": "Description",
        "capabilities": "Capabilities",
    }

    def __init__(
        self,
        name=None,
        is_default=None,
        external_group_name=None,
        description=None,
        capabilities=None,
        _configuration=None,
    ):
        """UserSiteCommonModelsNewRoleModel - a model defined in Swagger"""
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._name = None
        self._is_default = None
        self._external_group_name = None
        self._description = None
        self._capabilities = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if is_default is not None:
            self.is_default = is_default
        if external_group_name is not None:
            self.external_group_name = external_group_name
        if description is not None:
            self.description = description
        if capabilities is not None:
            self.capabilities = capabilities

    @property
    def name(self):
        # type: () -> str
        """Gets the name of this UserSiteCommonModelsNewRoleModel.


        :return: The name of this UserSiteCommonModelsNewRoleModel.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this UserSiteCommonModelsNewRoleModel.


        :param name: The name of this UserSiteCommonModelsNewRoleModel.
        :type: str
        """
        if self._configuration.client_side_validation and name is not None and len(name) > 256:
            raise ValueError("Invalid value for `name`, length must be less than or equal to `256`")
        if self._configuration.client_side_validation and name is not None and len(name) < 0:
            raise ValueError(
                "Invalid value for `name`, length must be greater than or equal to `0`"
            )

        self._name = name

    @property
    def is_default(self):
        # type: () -> bool
        """Gets the is_default of this UserSiteCommonModelsNewRoleModel.


        :return: The is_default of this UserSiteCommonModelsNewRoleModel.
        :rtype: bool
        """
        return self._is_default

    @is_default.setter
    def is_default(self, is_default):
        """Sets the is_default of this UserSiteCommonModelsNewRoleModel.


        :param is_default: The is_default of this UserSiteCommonModelsNewRoleModel.
        :type: bool
        """

        self._is_default = is_default

    @property
    def external_group_name(self):
        # type: () -> str
        """Gets the external_group_name of this UserSiteCommonModelsNewRoleModel.


        :return: The external_group_name of this UserSiteCommonModelsNewRoleModel.
        :rtype: str
        """
        return self._external_group_name

    @external_group_name.setter
    def external_group_name(self, external_group_name):
        """Sets the external_group_name of this UserSiteCommonModelsNewRoleModel.


        :param external_group_name: The external_group_name of this UserSiteCommonModelsNewRoleModel.
        :type: str
        """
        if (
            self._configuration.client_side_validation
            and external_group_name is not None
            and len(external_group_name) > 256
        ):
            raise ValueError(
                "Invalid value for `external_group_name`, length must be less than or equal to `256`"
            )
        if (
            self._configuration.client_side_validation
            and external_group_name is not None
            and len(external_group_name) < 0
        ):
            raise ValueError(
                "Invalid value for `external_group_name`, length must be greater than or equal to `0`"
            )

        self._external_group_name = external_group_name

    @property
    def description(self):
        # type: () -> str
        """Gets the description of this UserSiteCommonModelsNewRoleModel.


        :return: The description of this UserSiteCommonModelsNewRoleModel.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this UserSiteCommonModelsNewRoleModel.


        :param description: The description of this UserSiteCommonModelsNewRoleModel.
        :type: str
        """
        if (
            self._configuration.client_side_validation
            and description is not None
            and len(description) > 2048
        ):
            raise ValueError(
                "Invalid value for `description`, length must be less than or equal to `2048`"
            )
        if (
            self._configuration.client_side_validation
            and description is not None
            and len(description) < 0
        ):
            raise ValueError(
                "Invalid value for `description`, length must be greater than or equal to `0`"
            )

        self._description = description

    @property
    def capabilities(self):
        # type: () -> dict(str, bool)
        """Gets the capabilities of this UserSiteCommonModelsNewRoleModel.


        :return: The capabilities of this UserSiteCommonModelsNewRoleModel.
        :rtype: dict(str, bool)
        """
        return self._capabilities

    @capabilities.setter
    def capabilities(self, capabilities):
        """Sets the capabilities of this UserSiteCommonModelsNewRoleModel.


        :param capabilities: The capabilities of this UserSiteCommonModelsNewRoleModel.
        :type: dict(str, bool)
        """

        self._capabilities = capabilities

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in self.swagger_types.items():
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(UserSiteCommonModelsNewRoleModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UserSiteCommonModelsNewRoleModel):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UserSiteCommonModelsNewRoleModel):
            return True

        return self.to_dict() != other.to_dict()



"""
    HCL AppScan on Cloud (v2)

    This API allows you to interact with the service. The API allows you to perform many of the operations available in the UI and more.</br>For authentication, use the relevant APIs in the Account section. A successful authentication response includes a bearer token for use in subsequent API calls. Pasting this token in the 'Access token' field above will automatically add the authorization header to any API call that requires a valid session.

    OpenAPI spec version: v2

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

from pyasoc.configuration import Configuration


class UserSiteCommonModelsReportStatusModel:
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "id": "str",
        "name": "str",
        "status": "str",
        "progress": "int",
        "valid_until": "datetime",
        "html_instead_of_pdf": "bool",
        "download_link": "str",
        "report_file_type": "str",
    }

    attribute_map = {
        "id": "Id",
        "name": "Name",
        "status": "Status",
        "progress": "Progress",
        "valid_until": "ValidUntil",
        "html_instead_of_pdf": "HtmlInsteadOfPdf",
        "download_link": "DownloadLink",
        "report_file_type": "ReportFileType",
    }

    def __init__(
        self,
        id=None,
        name=None,
        status=None,
        progress=None,
        valid_until=None,
        html_instead_of_pdf=None,
        download_link=None,
        report_file_type=None,
        _configuration=None,
    ):
        """UserSiteCommonModelsReportStatusModel - a model defined in Swagger"""
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._name = None
        self._status = None
        self._progress = None
        self._valid_until = None
        self._html_instead_of_pdf = None
        self._download_link = None
        self._report_file_type = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if status is not None:
            self.status = status
        if progress is not None:
            self.progress = progress
        if valid_until is not None:
            self.valid_until = valid_until
        if html_instead_of_pdf is not None:
            self.html_instead_of_pdf = html_instead_of_pdf
        if download_link is not None:
            self.download_link = download_link
        if report_file_type is not None:
            self.report_file_type = report_file_type

    @property
    def id(self):
        # type: () -> str
        """Gets the id of this UserSiteCommonModelsReportStatusModel.


        :return: The id of this UserSiteCommonModelsReportStatusModel.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this UserSiteCommonModelsReportStatusModel.


        :param id: The id of this UserSiteCommonModelsReportStatusModel.
        :type: str
        """

        self._id = id

    @property
    def name(self):
        # type: () -> str
        """Gets the name of this UserSiteCommonModelsReportStatusModel.


        :return: The name of this UserSiteCommonModelsReportStatusModel.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this UserSiteCommonModelsReportStatusModel.


        :param name: The name of this UserSiteCommonModelsReportStatusModel.
        :type: str
        """

        self._name = name

    @property
    def status(self):
        # type: () -> str
        """Gets the status of this UserSiteCommonModelsReportStatusModel.


        :return: The status of this UserSiteCommonModelsReportStatusModel.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this UserSiteCommonModelsReportStatusModel.


        :param status: The status of this UserSiteCommonModelsReportStatusModel.
        :type: str
        """
        allowed_values = [
            "Pending",
            "Starting",
            "Running",
            "Failed",
            "Ready",
            "Deleted",
        ]
        if self._configuration.client_side_validation and status not in allowed_values:
            raise ValueError(
                f"Invalid value for `status` ({status}), must be one of {allowed_values}"
            )

        self._status = status

    @property
    def progress(self):
        # type: () -> int
        """Gets the progress of this UserSiteCommonModelsReportStatusModel.


        :return: The progress of this UserSiteCommonModelsReportStatusModel.
        :rtype: int
        """
        return self._progress

    @progress.setter
    def progress(self, progress):
        """Sets the progress of this UserSiteCommonModelsReportStatusModel.


        :param progress: The progress of this UserSiteCommonModelsReportStatusModel.
        :type: int
        """

        self._progress = progress

    @property
    def valid_until(self):
        # type: () -> datetime
        """Gets the valid_until of this UserSiteCommonModelsReportStatusModel.


        :return: The valid_until of this UserSiteCommonModelsReportStatusModel.
        :rtype: datetime
        """
        return self._valid_until

    @valid_until.setter
    def valid_until(self, valid_until):
        """Sets the valid_until of this UserSiteCommonModelsReportStatusModel.


        :param valid_until: The valid_until of this UserSiteCommonModelsReportStatusModel.
        :type: datetime
        """

        self._valid_until = valid_until

    @property
    def html_instead_of_pdf(self):
        # type: () -> bool
        """Gets the html_instead_of_pdf of this UserSiteCommonModelsReportStatusModel.


        :return: The html_instead_of_pdf of this UserSiteCommonModelsReportStatusModel.
        :rtype: bool
        """
        return self._html_instead_of_pdf

    @html_instead_of_pdf.setter
    def html_instead_of_pdf(self, html_instead_of_pdf):
        """Sets the html_instead_of_pdf of this UserSiteCommonModelsReportStatusModel.


        :param html_instead_of_pdf: The html_instead_of_pdf of this UserSiteCommonModelsReportStatusModel.
        :type: bool
        """

        self._html_instead_of_pdf = html_instead_of_pdf

    @property
    def download_link(self):
        # type: () -> str
        """Gets the download_link of this UserSiteCommonModelsReportStatusModel.


        :return: The download_link of this UserSiteCommonModelsReportStatusModel.
        :rtype: str
        """
        return self._download_link

    @download_link.setter
    def download_link(self, download_link):
        """Sets the download_link of this UserSiteCommonModelsReportStatusModel.


        :param download_link: The download_link of this UserSiteCommonModelsReportStatusModel.
        :type: str
        """

        self._download_link = download_link

    @property
    def report_file_type(self):
        # type: () -> str
        """Gets the report_file_type of this UserSiteCommonModelsReportStatusModel.


        :return: The report_file_type of this UserSiteCommonModelsReportStatusModel.
        :rtype: str
        """
        return self._report_file_type

    @report_file_type.setter
    def report_file_type(self, report_file_type):
        """Sets the report_file_type of this UserSiteCommonModelsReportStatusModel.


        :param report_file_type: The report_file_type of this UserSiteCommonModelsReportStatusModel.
        :type: str
        """

        self._report_file_type = report_file_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in self.swagger_types.items():
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(UserSiteCommonModelsReportStatusModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UserSiteCommonModelsReportStatusModel):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UserSiteCommonModelsReportStatusModel):
            return True

        return self.to_dict() != other.to_dict()



"""
    HCL AppScan on Cloud (v2)

    This API allows you to interact with the service. The API allows you to perform many of the operations available in the UI and more.</br>For authentication, use the relevant APIs in the Account section. A successful authentication response includes a bearer token for use in subsequent API calls. Pasting this token in the 'Access token' field above will automatically add the authorization header to any API call that requires a valid session.

    OpenAPI spec version: v2

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import re  # noqa: F401

# python 2 and python 3 compatibility library
from pyasoc.api_client import ApiClient
from pyasoc.models import UserSiteCommonModelsUploadViewModel


class FileUploadApi:
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def file_upload_upload(self, file_to_upload, **kwargs):
        """Upload file

        Upload a file to use in actions that require files (such as Create Scan and Execute Scan).<br />              Supported file formats: APK, CONFIG, CSV, IPA, IRX, SCAN, SCANT, JSON and ZIP.<br />              If ZIP or Json file is uploaded, 'fileType' parameter is required and the file must contain the appropriate content.<br />              Returns an ID for use as input for the other actions.<br />              Includes file format validation.<br />              The expected Content-Type of the request is multipart/form-data. The request should contain a single file parameter named \"fileToUpload\".<br />              The uploaded file will be available for use for 30 minutes. After this period, the file will be deleted from the server
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.file_upload_upload(file_to_upload, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param file file_to_upload: (required)
        :param str file_type: Uploaded File type (required for zip and postman collection json files only)
        :param str file_name: If provided, this parameter will override the name of the uploaded file, including its extension (APK, CONFIG, CSV, IPA, IRX, SCAN and SCANT).
        :return: UserSiteCommonModelsUploadViewModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.file_upload_upload_with_http_info(file_to_upload, **kwargs)
        else:
            (data) = self.file_upload_upload_with_http_info(file_to_upload, **kwargs)
            return data

    def file_upload_upload_with_http_info(
        self, file_to_upload, **kwargs
    ) -> UserSiteCommonModelsUploadViewModel:
        """Upload file

        Upload a file to use in actions that require files (such as Create Scan and Execute Scan).<br />              Supported file formats: APK, CONFIG, CSV, IPA, IRX, SCAN, SCANT, JSON and ZIP.<br />              If ZIP or Json file is uploaded, 'fileType' parameter is required and the file must contain the appropriate content.<br />              Returns an ID for use as input for the other actions.<br />              Includes file format validation.<br />              The expected Content-Type of the request is multipart/form-data. The request should contain a single file parameter named \"fileToUpload\".<br />              The uploaded file will be available for use for 30 minutes. After this period, the file will be deleted from the server
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.file_upload_upload_with_http_info(file_to_upload, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param file file_to_upload: (required)
        :param str file_type: Uploaded File type (required for zip and postman collection json files only)
        :param str file_name: If provided, this parameter will override the name of the uploaded file, including its extension (APK, CONFIG, CSV, IPA, IRX, SCAN and SCANT).
        :return: UserSiteCommonModelsUploadViewModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["file_to_upload", "file_type", "file_name"]
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in params["kwargs"].items():
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'" " to method file_upload_upload" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'file_to_upload' is set
        if self.api_client.client_side_validation and (
            "file_to_upload" not in params or params["file_to_upload"] is None
        ):
            raise ValueError(
                "Missing the required parameter `file_to_upload` when calling `file_upload_upload`"
            )

        if self.api_client.client_side_validation and (
            "file_name" in params and len(params["file_name"]) > 2048
        ):
            raise ValueError(
                "Invalid value for parameter `file_name` when calling `file_upload_upload`, length must be less than or equal to `2048`"
            )
        collection_formats = {}

        path_params = {}

        query_params = []
        if "file_type" in params:
            query_params.append(("fileType", params["file_type"]))

        header_params = {}

        form_params = []
        local_var_files = {}
        if "file_to_upload" in params:
            local_var_files["fileToUpload"] = params["file_to_upload"]
        if "file_name" in params:
            form_params.append(("fileName", params["file_name"]))

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "text/csv"]
        )

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(
            ["multipart/form-data"]
        )

        # Authentication setting
        auth_settings = ["AccessToken"]

        return self.api_client.call_api(
            "/api/v2/FileUpload",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="UserSiteCommonModelsUploadViewModel",
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )



"""
    HCL AppScan on Cloud (v2)

    This API allows you to interact with the service. The API allows you to perform many of the
    operations available in the UI and more.</br>For authentication, use the relevant APIs in
    the Account section. A successful authentication response includes a bearer token for use
    in subsequent API calls. Pasting this token in the 'Access token' field above will
    automatically add the authorization header to any API call that requires a valid session.

    OpenAPI spec version: v2

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401
from datetime import datetime

from pyasoc.configuration import Configuration


class UtilitiesSharedModelsCorrelationGroupModel:
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "id": "str",
        "application_id": "str",
        "status": "str",
        "severity": "str",
        "created_at": "datetime",
        "last_updated": "datetime",
        "last_found": "datetime",
        "api": "str",
        "issues_count": "int",
        "issue_type_id": "str",
        "issue_type": "str",
        "include_dast": "bool",
        "include_sast": "bool",
        "include_iast": "bool",
    }

    attribute_map = {
        "id": "Id",
        "application_id": "ApplicationId",
        "status": "Status",
        "severity": "Severity",
        "created_at": "CreatedAt",
        "last_updated": "LastUpdated",
        "last_found": "LastFound",
        "api": "Api",
        "issues_count": "IssuesCount",
        "issue_type_id": "IssueTypeId",
        "issue_type": "IssueType",
        "include_dast": "IncludeDast",
        "include_sast": "IncludeSast",
        "include_iast": "IncludeIast",
    }

    def __init__(
        self,
        id=None,
        application_id=None,
        status=None,
        severity=None,
        created_at=None,
        last_updated=None,
        last_found=None,
        api=None,
        issues_count=None,
        issue_type_id=None,
        issue_type=None,
        include_dast=None,
        include_sast=None,
        include_iast=None,
        _configuration=None,
    ):
        """UtilitiesSharedModelsCorrelationGroupModel - a model defined in Swagger"""
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._application_id = None
        self._status = None
        self._severity = None
        self._created_at = None
        self._last_updated = None
        self._last_found = None
        self._api = None
        self._issues_count = None
        self._issue_type_id = None
        self._issue_type = None
        self._include_dast = None
        self._include_sast = None
        self._include_iast = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if application_id is not None:
            self.application_id = application_id
        if status is not None:
            self.status = status
        if severity is not None:
            self.severity = severity
        if created_at is not None:
            self.created_at = created_at
        if last_updated is not None:
            self.last_updated = last_updated
        if last_found is not None:
            self.last_found = last_found
        if api is not None:
            self.api = api
        if issues_count is not None:
            self.issues_count = issues_count
        if issue_type_id is not None:
            self.issue_type_id = issue_type_id
        if issue_type is not None:
            self.issue_type = issue_type
        if include_dast is not None:
            self.include_dast = include_dast
        if include_sast is not None:
            self.include_sast = include_sast
        if include_iast is not None:
            self.include_iast = include_iast

    @property
    def id(self):
        # type: () -> str
        """Gets the id of this UtilitiesSharedModelsCorrelationGroupModel.


        :return: The id of this UtilitiesSharedModelsCorrelationGroupModel.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this UtilitiesSharedModelsCorrelationGroupModel.


        :param id: The id of this UtilitiesSharedModelsCorrelationGroupModel.
        :type: str
        """

        self._id = id

    @property
    def application_id(self):
        # type: () -> str
        """Gets the application_id of this UtilitiesSharedModelsCorrelationGroupModel.


        :return: The application_id of this UtilitiesSharedModelsCorrelationGroupModel.
        :rtype: str
        """
        return self._application_id

    @application_id.setter
    def application_id(self, application_id):
        """Sets the application_id of this UtilitiesSharedModelsCorrelationGroupModel.


        :param application_id: The application_id of this UtilitiesSharedModelsCorrelationGroupModel.
        :type: str
        """

        self._application_id = application_id

    @property
    def status(self):
        # type: () -> str
        """Gets the status of this UtilitiesSharedModelsCorrelationGroupModel.


        :return: The status of this UtilitiesSharedModelsCorrelationGroupModel.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this UtilitiesSharedModelsCorrelationGroupModel.


        :param status: The status of this UtilitiesSharedModelsCorrelationGroupModel.
        :type: str
        """
        allowed_values = [
            "Open",
            "InProgress",
            "Reopened",
            "Noise",
            "Passed",
            "Fixed",
            "New",
        ]
        if self._configuration.client_side_validation and status not in allowed_values:
            raise ValueError(
                f"Invalid value for `status` ({status}), must be one of {allowed_values}"
            )

        self._status = status

    @property
    def severity(self):
        # type: () -> str
        """Gets the severity of this UtilitiesSharedModelsCorrelationGroupModel.


        :return: The severity of this UtilitiesSharedModelsCorrelationGroupModel.
        :rtype: str
        """
        return self._severity

    @severity.setter
    def severity(self, severity):
        """Sets the severity of this UtilitiesSharedModelsCorrelationGroupModel.


        :param severity: The severity of this UtilitiesSharedModelsCorrelationGroupModel.
        :type: str
        """
        allowed_values = [
            "Undetermined",
            "Informational",
            "Low",
            "Medium",
            "High",
            "Critical",
        ]
        if self._configuration.client_side_validation and severity not in allowed_values:
            raise ValueError(
                "Invalid value for `severity` ({}), must be one of {}".format(
                    severity, allowed_values
                )
            )

        self._severity = severity

    @property
    def created_at(self):
        # type: () -> datetime
        """Gets the created_at of this UtilitiesSharedModelsCorrelationGroupModel.


        :return: The created_at of this UtilitiesSharedModelsCorrelationGroupModel.
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this UtilitiesSharedModelsCorrelationGroupModel.


        :param created_at: The created_at of this UtilitiesSharedModelsCorrelationGroupModel.
        :type: datetime
        """

        self._created_at = created_at

    @property
    def last_updated(self):
        # type: () -> datetime
        """Gets the last_updated of this UtilitiesSharedModelsCorrelationGroupModel.


        :return: The last_updated of this UtilitiesSharedModelsCorrelationGroupModel.
        :rtype: datetime
        """
        return self._last_updated

    @last_updated.setter
    def last_updated(self, last_updated):
        """Sets the last_updated of this UtilitiesSharedModelsCorrelationGroupModel.


        :param last_updated: The last_updated of this UtilitiesSharedModelsCorrelationGroupModel.
        :type: datetime
        """

        self._last_updated = last_updated

    @property
    def last_found(self):
        # type: () -> datetime
        """Gets the last_found of this UtilitiesSharedModelsCorrelationGroupModel.


        :return: The last_found of this UtilitiesSharedModelsCorrelationGroupModel.
        :rtype: datetime
        """
        return self._last_found

    @last_found.setter
    def last_found(self, last_found):
        """Sets the last_found of this UtilitiesSharedModelsCorrelationGroupModel.


        :param last_found: The last_found of this UtilitiesSharedModelsCorrelationGroupModel.
        :type: datetime
        """

        self._last_found = last_found

    @property
    def api(self):
        # type: () -> str
        """Gets the api of this UtilitiesSharedModelsCorrelationGroupModel.


        :return: The api of this UtilitiesSharedModelsCorrelationGroupModel.
        :rtype: str
        """
        return self._api

    @api.setter
    def api(self, api):
        """Sets the api of this UtilitiesSharedModelsCorrelationGroupModel.


        :param api: The api of this UtilitiesSharedModelsCorrelationGroupModel.
        :type: str
        """

        self._api = api

    @property
    def issues_count(self):
        # type: () -> int
        """Gets the issues_count of this UtilitiesSharedModelsCorrelationGroupModel.


        :return: The issues_count of this UtilitiesSharedModelsCorrelationGroupModel.
        :rtype: int
        """
        return self._issues_count

    @issues_count.setter
    def issues_count(self, issues_count):
        """Sets the issues_count of this UtilitiesSharedModelsCorrelationGroupModel.


        :param issues_count: The issues_count of this UtilitiesSharedModelsCorrelationGroupModel.
        :type: int
        """

        self._issues_count = issues_count

    @property
    def issue_type_id(self):
        # type: () -> str
        """Gets the issue_type_id of this UtilitiesSharedModelsCorrelationGroupModel.


        :return: The issue_type_id of this UtilitiesSharedModelsCorrelationGroupModel.
        :rtype: str
        """
        return self._issue_type_id

    @issue_type_id.setter
    def issue_type_id(self, issue_type_id):
        """Sets the issue_type_id of this UtilitiesSharedModelsCorrelationGroupModel.


        :param issue_type_id: The issue_type_id of this UtilitiesSharedModelsCorrelationGroupModel.
        :type: str
        """

        self._issue_type_id = issue_type_id

    @property
    def issue_type(self):
        # type: () -> str
        """Gets the issue_type of this UtilitiesSharedModelsCorrelationGroupModel.


        :return: The issue_type of this UtilitiesSharedModelsCorrelationGroupModel.
        :rtype: str
        """
        return self._issue_type

    @issue_type.setter
    def issue_type(self, issue_type):
        """Sets the issue_type of this UtilitiesSharedModelsCorrelationGroupModel.


        :param issue_type: The issue_type of this UtilitiesSharedModelsCorrelationGroupModel.
        :type: str
        """

        self._issue_type = issue_type

    @property
    def include_dast(self):
        # type: () -> bool
        """Gets the include_dast of this UtilitiesSharedModelsCorrelationGroupModel.


        :return: The include_dast of this UtilitiesSharedModelsCorrelationGroupModel.
        :rtype: bool
        """
        return self._include_dast

    @include_dast.setter
    def include_dast(self, include_dast):
        """Sets the include_dast of this UtilitiesSharedModelsCorrelationGroupModel.


        :param include_dast: The include_dast of this UtilitiesSharedModelsCorrelationGroupModel.
        :type: bool
        """

        self._include_dast = include_dast

    @property
    def include_sast(self):
        # type: () -> bool
        """Gets the include_sast of this UtilitiesSharedModelsCorrelationGroupModel.


        :return: The include_sast of this UtilitiesSharedModelsCorrelationGroupModel.
        :rtype: bool
        """
        return self._include_sast

    @include_sast.setter
    def include_sast(self, include_sast):
        """Sets the include_sast of this UtilitiesSharedModelsCorrelationGroupModel.


        :param include_sast: The include_sast of this UtilitiesSharedModelsCorrelationGroupModel.
        :type: bool
        """

        self._include_sast = include_sast

    @property
    def include_iast(self):
        # type: () -> bool
        """Gets the include_iast of this UtilitiesSharedModelsCorrelationGroupModel.


        :return: The include_iast of this UtilitiesSharedModelsCorrelationGroupModel.
        :rtype: bool
        """
        return self._include_iast

    @include_iast.setter
    def include_iast(self, include_iast):
        """Sets the include_iast of this UtilitiesSharedModelsCorrelationGroupModel.


        :param include_iast: The include_iast of this UtilitiesSharedModelsCorrelationGroupModel.
        :type: bool
        """

        self._include_iast = include_iast

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in self.swagger_types.items():
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(UtilitiesSharedModelsCorrelationGroupModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UtilitiesSharedModelsCorrelationGroupModel):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UtilitiesSharedModelsCorrelationGroupModel):
            return True

        return self.to_dict() != other.to_dict()



"""
    HCL AppScan on Cloud (v2)

    This API allows you to interact with the service. The API allows you to perform many of the operations available in the UI and more.</br>For authentication, use the relevant APIs in the Account section. A successful authentication response includes a bearer token for use in subsequent API calls. Pasting this token in the 'Access token' field above will automatically add the authorization header to any API call that requires a valid session.

    OpenAPI spec version: v2

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

from pyasoc.configuration import Configuration


class CommonModelsASMModelsApplicationModel:
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "id": "str",
        "name": "str",
        "risk_rating": "str",
        "critical_issues": "int",
        "high_issues": "int",
        "medium_issues": "int",
        "low_issues": "int",
        "informational_issues": "int",
        "issues_in_progress": "int",
        "max_severity": "str",
        "correlation_state": "str",
        "rr_max_severity": "int",
        "asset_group_id": "str",
        "business_impact": "str",
        "url": "str",
        "description": "str",
        "business_unit": "str",
        "business_unit_id": "str",
        "type": "str",
        "technology": "str",
        "testing_status": "str",
        "hosts": "str",
        "collateral_damage_potential": "str",
        "target_distribution": "str",
        "confidentiality_requirement": "str",
        "integrity_requirement": "str",
        "availability_requirement": "str",
        "tester": "str",
        "business_owner": "str",
        "development_contact": "str",
        "preferred_offering_type": "str",
        "asset_group_name": "str",
        "date_created": "datetime",
        "last_updated": "datetime",
        "last_comment": "datetime",
        "created_by": "str",
        "new_issues": "int",
        "open_issues": "int",
        "total_issues": "int",
        "overall_compliance": "bool",
        "compliance_statuses": "list[CommonModelsASMModelsComplianceStatus]",
        "can_be_deleted": "bool",
        "locked_to_subscription": "bool",
        "total_scans": "int",
        "n_scan_executions": "int",
        "has_exceeding_issues_number": "bool",
        "has_exceeding_scans_number": "bool",
        "auto_delete_exceeded_scans": "bool",
    }

    attribute_map = {
        "id": "Id",
        "name": "Name",
        "risk_rating": "RiskRating",
        "critical_issues": "CriticalIssues",
        "high_issues": "HighIssues",
        "medium_issues": "MediumIssues",
        "low_issues": "LowIssues",
        "informational_issues": "InformationalIssues",
        "issues_in_progress": "IssuesInProgress",
        "max_severity": "MaxSeverity",
        "correlation_state": "CorrelationState",
        "rr_max_severity": "RR_MaxSeverity",
        "asset_group_id": "AssetGroupId",
        "business_impact": "BusinessImpact",
        "url": "Url",
        "description": "Description",
        "business_unit": "BusinessUnit",
        "business_unit_id": "BusinessUnitId",
        "type": "Type",
        "technology": "Technology",
        "testing_status": "TestingStatus",
        "hosts": "Hosts",
        "collateral_damage_potential": "CollateralDamagePotential",
        "target_distribution": "TargetDistribution",
        "confidentiality_requirement": "ConfidentialityRequirement",
        "integrity_requirement": "IntegrityRequirement",
        "availability_requirement": "AvailabilityRequirement",
        "tester": "Tester",
        "business_owner": "BusinessOwner",
        "development_contact": "DevelopmentContact",
        "preferred_offering_type": "PreferredOfferingType",
        "asset_group_name": "AssetGroupName",
        "date_created": "DateCreated",
        "last_updated": "LastUpdated",
        "last_comment": "LastComment",
        "created_by": "CreatedBy",
        "new_issues": "NewIssues",
        "open_issues": "OpenIssues",
        "total_issues": "TotalIssues",
        "overall_compliance": "OverallCompliance",
        "compliance_statuses": "ComplianceStatuses",
        "can_be_deleted": "CanBeDeleted",
        "locked_to_subscription": "LockedToSubscription",
        "total_scans": "TotalScans",
        "n_scan_executions": "NScanExecutions",
        "has_exceeding_issues_number": "HasExceedingIssuesNumber",
        "has_exceeding_scans_number": "HasExceedingScansNumber",
        "auto_delete_exceeded_scans": "AutoDeleteExceededScans",
    }

    def __init__(
        self,
        id=None,
        name=None,
        risk_rating=None,
        critical_issues=None,
        high_issues=None,
        medium_issues=None,
        low_issues=None,
        informational_issues=None,
        issues_in_progress=None,
        max_severity=None,
        correlation_state=None,
        rr_max_severity=None,
        asset_group_id=None,
        business_impact=None,
        url=None,
        description=None,
        business_unit=None,
        business_unit_id=None,
        type=None,
        technology=None,
        testing_status=None,
        hosts=None,
        collateral_damage_potential=None,
        target_distribution=None,
        confidentiality_requirement=None,
        integrity_requirement=None,
        availability_requirement=None,
        tester=None,
        business_owner=None,
        development_contact=None,
        preferred_offering_type=None,
        asset_group_name=None,
        date_created=None,
        last_updated=None,
        last_comment=None,
        created_by=None,
        new_issues=None,
        open_issues=None,
        total_issues=None,
        overall_compliance=None,
        compliance_statuses=None,
        can_be_deleted=None,
        locked_to_subscription=None,
        total_scans=None,
        n_scan_executions=None,
        has_exceeding_issues_number=None,
        has_exceeding_scans_number=None,
        auto_delete_exceeded_scans=None,
        _configuration=None,
    ):
        """CommonModelsASMModelsApplicationModel - a model defined in Swagger"""
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._name = None
        self._risk_rating = None
        self._critical_issues = None
        self._high_issues = None
        self._medium_issues = None
        self._low_issues = None
        self._informational_issues = None
        self._issues_in_progress = None
        self._max_severity = None
        self._correlation_state = None
        self._rr_max_severity = None
        self._asset_group_id = None
        self._business_impact = None
        self._url = None
        self._description = None
        self._business_unit = None
        self._business_unit_id = None
        self._type = None
        self._technology = None
        self._testing_status = None
        self._hosts = None
        self._collateral_damage_potential = None
        self._target_distribution = None
        self._confidentiality_requirement = None
        self._integrity_requirement = None
        self._availability_requirement = None
        self._tester = None
        self._business_owner = None
        self._development_contact = None
        self._preferred_offering_type = None
        self._asset_group_name = None
        self._date_created = None
        self._last_updated = None
        self._last_comment = None
        self._created_by = None
        self._new_issues = None
        self._open_issues = None
        self._total_issues = None
        self._overall_compliance = None
        self._compliance_statuses = None
        self._can_be_deleted = None
        self._locked_to_subscription = None
        self._total_scans = None
        self._n_scan_executions = None
        self._has_exceeding_issues_number = None
        self._has_exceeding_scans_number = None
        self._auto_delete_exceeded_scans = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if risk_rating is not None:
            self.risk_rating = risk_rating
        if critical_issues is not None:
            self.critical_issues = critical_issues
        if high_issues is not None:
            self.high_issues = high_issues
        if medium_issues is not None:
            self.medium_issues = medium_issues
        if low_issues is not None:
            self.low_issues = low_issues
        if informational_issues is not None:
            self.informational_issues = informational_issues
        if issues_in_progress is not None:
            self.issues_in_progress = issues_in_progress
        if max_severity is not None:
            self.max_severity = max_severity
        if correlation_state is not None:
            self.correlation_state = correlation_state
        if rr_max_severity is not None:
            self.rr_max_severity = rr_max_severity
        if asset_group_id is not None:
            self.asset_group_id = asset_group_id
        if business_impact is not None:
            self.business_impact = business_impact
        if url is not None:
            self.url = url
        if description is not None:
            self.description = description
        if business_unit is not None:
            self.business_unit = business_unit
        if business_unit_id is not None:
            self.business_unit_id = business_unit_id
        if type is not None:
            self.type = type
        if technology is not None:
            self.technology = technology
        if testing_status is not None:
            self.testing_status = testing_status
        if hosts is not None:
            self.hosts = hosts
        if collateral_damage_potential is not None:
            self.collateral_damage_potential = collateral_damage_potential
        if target_distribution is not None:
            self.target_distribution = target_distribution
        if confidentiality_requirement is not None:
            self.confidentiality_requirement = confidentiality_requirement
        if integrity_requirement is not None:
            self.integrity_requirement = integrity_requirement
        if availability_requirement is not None:
            self.availability_requirement = availability_requirement
        if tester is not None:
            self.tester = tester
        if business_owner is not None:
            self.business_owner = business_owner
        if development_contact is not None:
            self.development_contact = development_contact
        if preferred_offering_type is not None:
            self.preferred_offering_type = preferred_offering_type
        if asset_group_name is not None:
            self.asset_group_name = asset_group_name
        if date_created is not None:
            self.date_created = date_created
        if last_updated is not None:
            self.last_updated = last_updated
        if last_comment is not None:
            self.last_comment = last_comment
        if created_by is not None:
            self.created_by = created_by
        if new_issues is not None:
            self.new_issues = new_issues
        if open_issues is not None:
            self.open_issues = open_issues
        if total_issues is not None:
            self.total_issues = total_issues
        if overall_compliance is not None:
            self.overall_compliance = overall_compliance
        if compliance_statuses is not None:
            self.compliance_statuses = compliance_statuses
        if can_be_deleted is not None:
            self.can_be_deleted = can_be_deleted
        if locked_to_subscription is not None:
            self.locked_to_subscription = locked_to_subscription
        if total_scans is not None:
            self.total_scans = total_scans
        if n_scan_executions is not None:
            self.n_scan_executions = n_scan_executions
        if has_exceeding_issues_number is not None:
            self.has_exceeding_issues_number = has_exceeding_issues_number
        if has_exceeding_scans_number is not None:
            self.has_exceeding_scans_number = has_exceeding_scans_number
        if auto_delete_exceeded_scans is not None:
            self.auto_delete_exceeded_scans = auto_delete_exceeded_scans

    @property
    def id(self):
        # type: () -> str
        """Gets the id of this CommonModelsASMModelsApplicationModel.


        :return: The id of this CommonModelsASMModelsApplicationModel.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this CommonModelsASMModelsApplicationModel.


        :param id: The id of this CommonModelsASMModelsApplicationModel.
        :type: str
        """

        self._id = id

    @property
    def name(self):
        # type: () -> str
        """Gets the name of this CommonModelsASMModelsApplicationModel.


        :return: The name of this CommonModelsASMModelsApplicationModel.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CommonModelsASMModelsApplicationModel.


        :param name: The name of this CommonModelsASMModelsApplicationModel.
        :type: str
        """
        if self._configuration.client_side_validation and name is not None and len(name) > 64:
            raise ValueError("Invalid value for `name`, length must be less than or equal to `64`")
        if self._configuration.client_side_validation and name is not None and len(name) < 0:
            raise ValueError(
                "Invalid value for `name`, length must be greater than or equal to `0`"
            )

        self._name = name

    @property
    def risk_rating(self):
        # type: () -> str
        """Gets the risk_rating of this CommonModelsASMModelsApplicationModel.


        :return: The risk_rating of this CommonModelsASMModelsApplicationModel.
        :rtype: str
        """
        return self._risk_rating

    @risk_rating.setter
    def risk_rating(self, risk_rating):
        """Sets the risk_rating of this CommonModelsASMModelsApplicationModel.


        :param risk_rating: The risk_rating of this CommonModelsASMModelsApplicationModel.
        :type: str
        """
        allowed_values = ["Unknown", "Low", "Medium", "High", "Critical"]
        if self._configuration.client_side_validation and risk_rating not in allowed_values:
            raise ValueError(
                "Invalid value for `risk_rating` ({}), must be one of {}".format(
                    risk_rating, allowed_values
                )
            )

        self._risk_rating = risk_rating

    @property
    def critical_issues(self):
        # type: () -> int
        """Gets the critical_issues of this CommonModelsASMModelsApplicationModel.


        :return: The critical_issues of this CommonModelsASMModelsApplicationModel.
        :rtype: int
        """
        return self._critical_issues

    @critical_issues.setter
    def critical_issues(self, critical_issues):
        """Sets the critical_issues of this CommonModelsASMModelsApplicationModel.


        :param critical_issues: The critical_issues of this CommonModelsASMModelsApplicationModel.
        :type: int
        """

        self._critical_issues = critical_issues

    @property
    def high_issues(self):
        # type: () -> int
        """Gets the high_issues of this CommonModelsASMModelsApplicationModel.


        :return: The high_issues of this CommonModelsASMModelsApplicationModel.
        :rtype: int
        """
        return self._high_issues

    @high_issues.setter
    def high_issues(self, high_issues):
        """Sets the high_issues of this CommonModelsASMModelsApplicationModel.


        :param high_issues: The high_issues of this CommonModelsASMModelsApplicationModel.
        :type: int
        """

        self._high_issues = high_issues

    @property
    def medium_issues(self):
        # type: () -> int
        """Gets the medium_issues of this CommonModelsASMModelsApplicationModel.


        :return: The medium_issues of this CommonModelsASMModelsApplicationModel.
        :rtype: int
        """
        return self._medium_issues

    @medium_issues.setter
    def medium_issues(self, medium_issues):
        """Sets the medium_issues of this CommonModelsASMModelsApplicationModel.


        :param medium_issues: The medium_issues of this CommonModelsASMModelsApplicationModel.
        :type: int
        """

        self._medium_issues = medium_issues

    @property
    def low_issues(self):
        # type: () -> int
        """Gets the low_issues of this CommonModelsASMModelsApplicationModel.


        :return: The low_issues of this CommonModelsASMModelsApplicationModel.
        :rtype: int
        """
        return self._low_issues

    @low_issues.setter
    def low_issues(self, low_issues):
        """Sets the low_issues of this CommonModelsASMModelsApplicationModel.


        :param low_issues: The low_issues of this CommonModelsASMModelsApplicationModel.
        :type: int
        """

        self._low_issues = low_issues

    @property
    def informational_issues(self):
        # type: () -> int
        """Gets the informational_issues of this CommonModelsASMModelsApplicationModel.


        :return: The informational_issues of this CommonModelsASMModelsApplicationModel.
        :rtype: int
        """
        return self._informational_issues

    @informational_issues.setter
    def informational_issues(self, informational_issues):
        """Sets the informational_issues of this CommonModelsASMModelsApplicationModel.


        :param informational_issues: The informational_issues of this CommonModelsASMModelsApplicationModel.
        :type: int
        """

        self._informational_issues = informational_issues

    @property
    def issues_in_progress(self):
        # type: () -> int
        """Gets the issues_in_progress of this CommonModelsASMModelsApplicationModel.


        :return: The issues_in_progress of this CommonModelsASMModelsApplicationModel.
        :rtype: int
        """
        return self._issues_in_progress

    @issues_in_progress.setter
    def issues_in_progress(self, issues_in_progress):
        """Sets the issues_in_progress of this CommonModelsASMModelsApplicationModel.


        :param issues_in_progress: The issues_in_progress of this CommonModelsASMModelsApplicationModel.
        :type: int
        """

        self._issues_in_progress = issues_in_progress

    @property
    def max_severity(self):
        # type: () -> str
        """Gets the max_severity of this CommonModelsASMModelsApplicationModel.


        :return: The max_severity of this CommonModelsASMModelsApplicationModel.
        :rtype: str
        """
        return self._max_severity

    @max_severity.setter
    def max_severity(self, max_severity):
        """Sets the max_severity of this CommonModelsASMModelsApplicationModel.


        :param max_severity: The max_severity of this CommonModelsASMModelsApplicationModel.
        :type: str
        """
        allowed_values = [
            "Undetermined",
            "Informational",
            "Low",
            "Medium",
            "High",
            "Critical",
        ]
        if self._configuration.client_side_validation and max_severity not in allowed_values:
            raise ValueError(
                "Invalid value for `max_severity` ({}), must be one of {}".format(
                    max_severity, allowed_values
                )
            )

        self._max_severity = max_severity

    @property
    def correlation_state(self):
        # type: () -> str
        """Gets the correlation_state of this CommonModelsASMModelsApplicationModel.


        :return: The correlation_state of this CommonModelsASMModelsApplicationModel.
        :rtype: str
        """
        return self._correlation_state

    @correlation_state.setter
    def correlation_state(self, correlation_state):
        """Sets the correlation_state of this CommonModelsASMModelsApplicationModel.


        :param correlation_state: The correlation_state of this CommonModelsASMModelsApplicationModel.
        :type: str
        """
        allowed_values = ["None", "Active", "InProgress"]
        if self._configuration.client_side_validation and correlation_state not in allowed_values:
            raise ValueError(
                "Invalid value for `correlation_state` ({}), must be one of {}".format(
                    correlation_state, allowed_values
                )
            )

        self._correlation_state = correlation_state

    @property
    def rr_max_severity(self):
        # type: () -> int
        """Gets the rr_max_severity of this CommonModelsASMModelsApplicationModel.


        :return: The rr_max_severity of this CommonModelsASMModelsApplicationModel.
        :rtype: int
        """
        return self._rr_max_severity

    @rr_max_severity.setter
    def rr_max_severity(self, rr_max_severity):
        """Sets the rr_max_severity of this CommonModelsASMModelsApplicationModel.


        :param rr_max_severity: The rr_max_severity of this CommonModelsASMModelsApplicationModel.
        :type: int
        """

        self._rr_max_severity = rr_max_severity

    @property
    def asset_group_id(self):
        # type: () -> str
        """Gets the asset_group_id of this CommonModelsASMModelsApplicationModel.


        :return: The asset_group_id of this CommonModelsASMModelsApplicationModel.
        :rtype: str
        """
        return self._asset_group_id

    @asset_group_id.setter
    def asset_group_id(self, asset_group_id):
        """Sets the asset_group_id of this CommonModelsASMModelsApplicationModel.


        :param asset_group_id: The asset_group_id of this CommonModelsASMModelsApplicationModel.
        :type: str
        """

        self._asset_group_id = asset_group_id

    @property
    def business_impact(self):
        # type: () -> str
        """Gets the business_impact of this CommonModelsASMModelsApplicationModel.


        :return: The business_impact of this CommonModelsASMModelsApplicationModel.
        :rtype: str
        """
        return self._business_impact

    @business_impact.setter
    def business_impact(self, business_impact):
        """Sets the business_impact of this CommonModelsASMModelsApplicationModel.


        :param business_impact: The business_impact of this CommonModelsASMModelsApplicationModel.
        :type: str
        """
        allowed_values = [
            "Unspecified",
            "Low",
            "Medium",
            "High",
            "Critical",
        ]
        if self._configuration.client_side_validation and business_impact not in allowed_values:
            raise ValueError(
                "Invalid value for `business_impact` ({}), must be one of {}".format(
                    business_impact, allowed_values
                )
            )

        self._business_impact = business_impact

    @property
    def url(self):
        # type: () -> str
        """Gets the url of this CommonModelsASMModelsApplicationModel.


        :return: The url of this CommonModelsASMModelsApplicationModel.
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this CommonModelsASMModelsApplicationModel.


        :param url: The url of this CommonModelsASMModelsApplicationModel.
        :type: str
        """

        self._url = url

    @property
    def description(self):
        # type: () -> str
        """Gets the description of this CommonModelsASMModelsApplicationModel.


        :return: The description of this CommonModelsASMModelsApplicationModel.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this CommonModelsASMModelsApplicationModel.


        :param description: The description of this CommonModelsASMModelsApplicationModel.
        :type: str
        """

        self._description = description

    @property
    def business_unit(self):
        # type: () -> str
        """Gets the business_unit of this CommonModelsASMModelsApplicationModel.


        :return: The business_unit of this CommonModelsASMModelsApplicationModel.
        :rtype: str
        """
        return self._business_unit

    @business_unit.setter
    def business_unit(self, business_unit):
        """Sets the business_unit of this CommonModelsASMModelsApplicationModel.


        :param business_unit: The business_unit of this CommonModelsASMModelsApplicationModel.
        :type: str
        """

        self._business_unit = business_unit

    @property
    def business_unit_id(self):
        # type: () -> str
        """Gets the business_unit_id of this CommonModelsASMModelsApplicationModel.


        :return: The business_unit_id of this CommonModelsASMModelsApplicationModel.
        :rtype: str
        """
        return self._business_unit_id

    @business_unit_id.setter
    def business_unit_id(self, business_unit_id):
        """Sets the business_unit_id of this CommonModelsASMModelsApplicationModel.


        :param business_unit_id: The business_unit_id of this CommonModelsASMModelsApplicationModel.
        :type: str
        """

        self._business_unit_id = business_unit_id

    @property
    def type(self):
        # type: () -> str
        """Gets the type of this CommonModelsASMModelsApplicationModel.


        :return: The type of this CommonModelsASMModelsApplicationModel.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this CommonModelsASMModelsApplicationModel.


        :param type: The type of this CommonModelsASMModelsApplicationModel.
        :type: str
        """

        self._type = type

    @property
    def technology(self):
        # type: () -> str
        """Gets the technology of this CommonModelsASMModelsApplicationModel.


        :return: The technology of this CommonModelsASMModelsApplicationModel.
        :rtype: str
        """
        return self._technology

    @technology.setter
    def technology(self, technology):
        """Sets the technology of this CommonModelsASMModelsApplicationModel.


        :param technology: The technology of this CommonModelsASMModelsApplicationModel.
        :type: str
        """

        self._technology = technology

    @property
    def testing_status(self):
        # type: () -> str
        """Gets the testing_status of this CommonModelsASMModelsApplicationModel.


        :return: The testing_status of this CommonModelsASMModelsApplicationModel.
        :rtype: str
        """
        return self._testing_status

    @testing_status.setter
    def testing_status(self, testing_status):
        """Sets the testing_status of this CommonModelsASMModelsApplicationModel.


        :param testing_status: The testing_status of this CommonModelsASMModelsApplicationModel.
        :type: str
        """
        allowed_values = ["NotStarted", "InProgress", "Completed"]
        if self._configuration.client_side_validation and testing_status not in allowed_values:
            raise ValueError(
                "Invalid value for `testing_status` ({}), must be one of {}".format(
                    testing_status, allowed_values
                )
            )

        self._testing_status = testing_status

    @property
    def hosts(self):
        # type: () -> str
        """Gets the hosts of this CommonModelsASMModelsApplicationModel.


        :return: The hosts of this CommonModelsASMModelsApplicationModel.
        :rtype: str
        """
        return self._hosts

    @hosts.setter
    def hosts(self, hosts):
        """Sets the hosts of this CommonModelsASMModelsApplicationModel.


        :param hosts: The hosts of this CommonModelsASMModelsApplicationModel.
        :type: str
        """

        self._hosts = hosts

    @property
    def collateral_damage_potential(self):
        # type: () -> str
        """Gets the collateral_damage_potential of this CommonModelsASMModelsApplicationModel.


        :return: The collateral_damage_potential of this CommonModelsASMModelsApplicationModel.
        :rtype: str
        """
        return self._collateral_damage_potential

    @collateral_damage_potential.setter
    def collateral_damage_potential(self, collateral_damage_potential):
        """Sets the collateral_damage_potential of this CommonModelsASMModelsApplicationModel.


        :param collateral_damage_potential: The collateral_damage_potential of this CommonModelsASMModelsApplicationModel.
        :type: str
        """
        allowed_values = [
            "NotDefined",
            "None",
            "Low",
            "LowMedium",
            "MediumHigh",
            "High",
        ]
        if (
            self._configuration.client_side_validation
            and collateral_damage_potential not in allowed_values
        ):
            raise ValueError(
                "Invalid value for `collateral_damage_potential` ({}), must be one of {}".format(
                    collateral_damage_potential, allowed_values
                )
            )

        self._collateral_damage_potential = collateral_damage_potential

    @property
    def target_distribution(self):
        # type: () -> str
        """Gets the target_distribution of this CommonModelsASMModelsApplicationModel.


        :return: The target_distribution of this CommonModelsASMModelsApplicationModel.
        :rtype: str
        """
        return self._target_distribution

    @target_distribution.setter
    def target_distribution(self, target_distribution):
        """Sets the target_distribution of this CommonModelsASMModelsApplicationModel.


        :param target_distribution: The target_distribution of this CommonModelsASMModelsApplicationModel.
        :type: str
        """
        allowed_values = ["NotDefined", "None", "Low", "Medium", "High"]
        if self._configuration.client_side_validation and target_distribution not in allowed_values:
            raise ValueError(
                "Invalid value for `target_distribution` ({}), must be one of {}".format(
                    target_distribution, allowed_values
                )
            )

        self._target_distribution = target_distribution

    @property
    def confidentiality_requirement(self):
        # type: () -> str
        """Gets the confidentiality_requirement of this CommonModelsASMModelsApplicationModel.


        :return: The confidentiality_requirement of this CommonModelsASMModelsApplicationModel.
        :rtype: str
        """
        return self._confidentiality_requirement

    @confidentiality_requirement.setter
    def confidentiality_requirement(self, confidentiality_requirement):
        """Sets the confidentiality_requirement of this CommonModelsASMModelsApplicationModel.


        :param confidentiality_requirement: The confidentiality_requirement of this CommonModelsASMModelsApplicationModel.
        :type: str
        """
        allowed_values = ["NotDefined", "Low", "Medium", "High"]
        if (
            self._configuration.client_side_validation
            and confidentiality_requirement not in allowed_values
        ):
            raise ValueError(
                "Invalid value for `confidentiality_requirement` ({}), must be one of {}".format(
                    confidentiality_requirement, allowed_values
                )
            )

        self._confidentiality_requirement = confidentiality_requirement

    @property
    def integrity_requirement(self):
        # type: () -> str
        """Gets the integrity_requirement of this CommonModelsASMModelsApplicationModel.


        :return: The integrity_requirement of this CommonModelsASMModelsApplicationModel.
        :rtype: str
        """
        return self._integrity_requirement

    @integrity_requirement.setter
    def integrity_requirement(self, integrity_requirement):
        """Sets the integrity_requirement of this CommonModelsASMModelsApplicationModel.


        :param integrity_requirement: The integrity_requirement of this CommonModelsASMModelsApplicationModel.
        :type: str
        """
        allowed_values = ["NotDefined", "Low", "Medium", "High"]
        if (
            self._configuration.client_side_validation
            and integrity_requirement not in allowed_values
        ):
            raise ValueError(
                "Invalid value for `integrity_requirement` ({}), must be one of {}".format(
                    integrity_requirement, allowed_values
                )
            )

        self._integrity_requirement = integrity_requirement

    @property
    def availability_requirement(self):
        # type: () -> str
        """Gets the availability_requirement of this CommonModelsASMModelsApplicationModel.


        :return: The availability_requirement of this CommonModelsASMModelsApplicationModel.
        :rtype: str
        """
        return self._availability_requirement

    @availability_requirement.setter
    def availability_requirement(self, availability_requirement):
        """Sets the availability_requirement of this CommonModelsASMModelsApplicationModel.


        :param availability_requirement: The availability_requirement of this CommonModelsASMModelsApplicationModel.
        :type: str
        """
        allowed_values = ["NotDefined", "Low", "Medium", "High"]
        if (
            self._configuration.client_side_validation
            and availability_requirement not in allowed_values
        ):
            raise ValueError(
                "Invalid value for `availability_requirement` ({}), must be one of {}".format(
                    availability_requirement, allowed_values
                )
            )

        self._availability_requirement = availability_requirement

    @property
    def tester(self):
        # type: () -> str
        """Gets the tester of this CommonModelsASMModelsApplicationModel.


        :return: The tester of this CommonModelsASMModelsApplicationModel.
        :rtype: str
        """
        return self._tester

    @tester.setter
    def tester(self, tester):
        """Sets the tester of this CommonModelsASMModelsApplicationModel.


        :param tester: The tester of this CommonModelsASMModelsApplicationModel.
        :type: str
        """

        self._tester = tester

    @property
    def business_owner(self):
        # type: () -> str
        """Gets the business_owner of this CommonModelsASMModelsApplicationModel.


        :return: The business_owner of this CommonModelsASMModelsApplicationModel.
        :rtype: str
        """
        return self._business_owner

    @business_owner.setter
    def business_owner(self, business_owner):
        """Sets the business_owner of this CommonModelsASMModelsApplicationModel.


        :param business_owner: The business_owner of this CommonModelsASMModelsApplicationModel.
        :type: str
        """

        self._business_owner = business_owner

    @property
    def development_contact(self):
        # type: () -> str
        """Gets the development_contact of this CommonModelsASMModelsApplicationModel.


        :return: The development_contact of this CommonModelsASMModelsApplicationModel.
        :rtype: str
        """
        return self._development_contact

    @development_contact.setter
    def development_contact(self, development_contact):
        """Sets the development_contact of this CommonModelsASMModelsApplicationModel.


        :param development_contact: The development_contact of this CommonModelsASMModelsApplicationModel.
        :type: str
        """

        self._development_contact = development_contact

    @property
    def preferred_offering_type(self):
        # type: () -> str
        """Gets the preferred_offering_type of this CommonModelsASMModelsApplicationModel.


        :return: The preferred_offering_type of this CommonModelsASMModelsApplicationModel.
        :rtype: str
        """
        return self._preferred_offering_type

    @preferred_offering_type.setter
    def preferred_offering_type(self, preferred_offering_type):
        """Sets the preferred_offering_type of this CommonModelsASMModelsApplicationModel.


        :param preferred_offering_type: The preferred_offering_type of this CommonModelsASMModelsApplicationModel.
        :type: str
        """
        allowed_values = ["None", "ScanExecution", "Applications"]
        if (
            self._configuration.client_side_validation
            and preferred_offering_type not in allowed_values
        ):
            raise ValueError(
                "Invalid value for `preferred_offering_type` ({}), must be one of {}".format(
                    preferred_offering_type, allowed_values
                )
            )

        self._preferred_offering_type = preferred_offering_type

    @property
    def asset_group_name(self):
        # type: () -> str
        """Gets the asset_group_name of this CommonModelsASMModelsApplicationModel.


        :return: The asset_group_name of this CommonModelsASMModelsApplicationModel.
        :rtype: str
        """
        return self._asset_group_name

    @asset_group_name.setter
    def asset_group_name(self, asset_group_name):
        """Sets the asset_group_name of this CommonModelsASMModelsApplicationModel.


        :param asset_group_name: The asset_group_name of this CommonModelsASMModelsApplicationModel.
        :type: str
        """

        self._asset_group_name = asset_group_name

    @property
    def date_created(self):
        # type: () -> datetime
        """Gets the date_created of this CommonModelsASMModelsApplicationModel.


        :return: The date_created of this CommonModelsASMModelsApplicationModel.
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """Sets the date_created of this CommonModelsASMModelsApplicationModel.


        :param date_created: The date_created of this CommonModelsASMModelsApplicationModel.
        :type: datetime
        """

        self._date_created = date_created

    @property
    def last_updated(self):
        # type: () -> datetime
        """Gets the last_updated of this CommonModelsASMModelsApplicationModel.


        :return: The last_updated of this CommonModelsASMModelsApplicationModel.
        :rtype: datetime
        """
        return self._last_updated

    @last_updated.setter
    def last_updated(self, last_updated):
        """Sets the last_updated of this CommonModelsASMModelsApplicationModel.


        :param last_updated: The last_updated of this CommonModelsASMModelsApplicationModel.
        :type: datetime
        """

        self._last_updated = last_updated

    @property
    def last_comment(self):
        # type: () -> datetime
        """Gets the last_comment of this CommonModelsASMModelsApplicationModel.


        :return: The last_comment of this CommonModelsASMModelsApplicationModel.
        :rtype: datetime
        """
        return self._last_comment

    @last_comment.setter
    def last_comment(self, last_comment):
        """Sets the last_comment of this CommonModelsASMModelsApplicationModel.


        :param last_comment: The last_comment of this CommonModelsASMModelsApplicationModel.
        :type: datetime
        """

        self._last_comment = last_comment

    @property
    def created_by(self):
        # type: () -> str
        """Gets the created_by of this CommonModelsASMModelsApplicationModel.


        :return: The created_by of this CommonModelsASMModelsApplicationModel.
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this CommonModelsASMModelsApplicationModel.


        :param created_by: The created_by of this CommonModelsASMModelsApplicationModel.
        :type: str
        """

        self._created_by = created_by

    @property
    def new_issues(self):
        # type: () -> int
        """Gets the new_issues of this CommonModelsASMModelsApplicationModel.


        :return: The new_issues of this CommonModelsASMModelsApplicationModel.
        :rtype: int
        """
        return self._new_issues

    @new_issues.setter
    def new_issues(self, new_issues):
        """Sets the new_issues of this CommonModelsASMModelsApplicationModel.


        :param new_issues: The new_issues of this CommonModelsASMModelsApplicationModel.
        :type: int
        """

        self._new_issues = new_issues

    @property
    def open_issues(self):
        # type: () -> int
        """Gets the open_issues of this CommonModelsASMModelsApplicationModel.


        :return: The open_issues of this CommonModelsASMModelsApplicationModel.
        :rtype: int
        """
        return self._open_issues

    @open_issues.setter
    def open_issues(self, open_issues):
        """Sets the open_issues of this CommonModelsASMModelsApplicationModel.


        :param open_issues: The open_issues of this CommonModelsASMModelsApplicationModel.
        :type: int
        """

        self._open_issues = open_issues

    @property
    def total_issues(self):
        # type: () -> int
        """Gets the total_issues of this CommonModelsASMModelsApplicationModel.


        :return: The total_issues of this CommonModelsASMModelsApplicationModel.
        :rtype: int
        """
        return self._total_issues

    @total_issues.setter
    def total_issues(self, total_issues):
        """Sets the total_issues of this CommonModelsASMModelsApplicationModel.


        :param total_issues: The total_issues of this CommonModelsASMModelsApplicationModel.
        :type: int
        """

        self._total_issues = total_issues

    @property
    def overall_compliance(self):
        # type: () -> bool
        """Gets the overall_compliance of this CommonModelsASMModelsApplicationModel.


        :return: The overall_compliance of this CommonModelsASMModelsApplicationModel.
        :rtype: bool
        """
        return self._overall_compliance

    @overall_compliance.setter
    def overall_compliance(self, overall_compliance):
        """Sets the overall_compliance of this CommonModelsASMModelsApplicationModel.


        :param overall_compliance: The overall_compliance of this CommonModelsASMModelsApplicationModel.
        :type: bool
        """

        self._overall_compliance = overall_compliance

    @property
    def compliance_statuses(self):
        # type: () -> list[CommonModelsASMModelsComplianceStatus]
        """Gets the compliance_statuses of this CommonModelsASMModelsApplicationModel.


        :return: The compliance_statuses of this CommonModelsASMModelsApplicationModel.
        :rtype: list[CommonModelsASMModelsComplianceStatus]
        """
        return self._compliance_statuses

    @compliance_statuses.setter
    def compliance_statuses(self, compliance_statuses):
        """Sets the compliance_statuses of this CommonModelsASMModelsApplicationModel.


        :param compliance_statuses: The compliance_statuses of this CommonModelsASMModelsApplicationModel.
        :type: list[CommonModelsASMModelsComplianceStatus]
        """

        self._compliance_statuses = compliance_statuses

    @property
    def can_be_deleted(self):
        # type: () -> bool
        """Gets the can_be_deleted of this CommonModelsASMModelsApplicationModel.


        :return: The can_be_deleted of this CommonModelsASMModelsApplicationModel.
        :rtype: bool
        """
        return self._can_be_deleted

    @can_be_deleted.setter
    def can_be_deleted(self, can_be_deleted):
        """Sets the can_be_deleted of this CommonModelsASMModelsApplicationModel.


        :param can_be_deleted: The can_be_deleted of this CommonModelsASMModelsApplicationModel.
        :type: bool
        """

        self._can_be_deleted = can_be_deleted

    @property
    def locked_to_subscription(self):
        # type: () -> bool
        """Gets the locked_to_subscription of this CommonModelsASMModelsApplicationModel.


        :return: The locked_to_subscription of this CommonModelsASMModelsApplicationModel.
        :rtype: bool
        """
        return self._locked_to_subscription

    @locked_to_subscription.setter
    def locked_to_subscription(self, locked_to_subscription):
        """Sets the locked_to_subscription of this CommonModelsASMModelsApplicationModel.


        :param locked_to_subscription: The locked_to_subscription of this CommonModelsASMModelsApplicationModel.
        :type: bool
        """

        self._locked_to_subscription = locked_to_subscription

    @property
    def total_scans(self):
        # type: () -> int
        """Gets the total_scans of this CommonModelsASMModelsApplicationModel.


        :return: The total_scans of this CommonModelsASMModelsApplicationModel.
        :rtype: int
        """
        return self._total_scans

    @total_scans.setter
    def total_scans(self, total_scans):
        """Sets the total_scans of this CommonModelsASMModelsApplicationModel.


        :param total_scans: The total_scans of this CommonModelsASMModelsApplicationModel.
        :type: int
        """

        self._total_scans = total_scans

    @property
    def n_scan_executions(self):
        # type: () -> int
        """Gets the n_scan_executions of this CommonModelsASMModelsApplicationModel.


        :return: The n_scan_executions of this CommonModelsASMModelsApplicationModel.
        :rtype: int
        """
        return self._n_scan_executions

    @n_scan_executions.setter
    def n_scan_executions(self, n_scan_executions):
        """Sets the n_scan_executions of this CommonModelsASMModelsApplicationModel.


        :param n_scan_executions: The n_scan_executions of this CommonModelsASMModelsApplicationModel.
        :type: int
        """

        self._n_scan_executions = n_scan_executions

    @property
    def has_exceeding_issues_number(self):
        # type: () -> bool
        """Gets the has_exceeding_issues_number of this CommonModelsASMModelsApplicationModel.


        :return: The has_exceeding_issues_number of this CommonModelsASMModelsApplicationModel.
        :rtype: bool
        """
        return self._has_exceeding_issues_number

    @has_exceeding_issues_number.setter
    def has_exceeding_issues_number(self, has_exceeding_issues_number):
        """Sets the has_exceeding_issues_number of this CommonModelsASMModelsApplicationModel.


        :param has_exceeding_issues_number: The has_exceeding_issues_number of this CommonModelsASMModelsApplicationModel.
        :type: bool
        """

        self._has_exceeding_issues_number = has_exceeding_issues_number

    @property
    def has_exceeding_scans_number(self):
        # type: () -> bool
        """Gets the has_exceeding_scans_number of this CommonModelsASMModelsApplicationModel.


        :return: The has_exceeding_scans_number of this CommonModelsASMModelsApplicationModel.
        :rtype: bool
        """
        return self._has_exceeding_scans_number

    @has_exceeding_scans_number.setter
    def has_exceeding_scans_number(self, has_exceeding_scans_number):
        """Sets the has_exceeding_scans_number of this CommonModelsASMModelsApplicationModel.


        :param has_exceeding_scans_number: The has_exceeding_scans_number of this CommonModelsASMModelsApplicationModel.
        :type: bool
        """

        self._has_exceeding_scans_number = has_exceeding_scans_number

    @property
    def auto_delete_exceeded_scans(self):
        # type: () -> bool
        """Gets the auto_delete_exceeded_scans of this CommonModelsASMModelsApplicationModel.


        :return: The auto_delete_exceeded_scans of this CommonModelsASMModelsApplicationModel.
        :rtype: bool
        """
        return self._auto_delete_exceeded_scans

    @auto_delete_exceeded_scans.setter
    def auto_delete_exceeded_scans(self, auto_delete_exceeded_scans):
        """Sets the auto_delete_exceeded_scans of this CommonModelsASMModelsApplicationModel.


        :param auto_delete_exceeded_scans: The auto_delete_exceeded_scans of this CommonModelsASMModelsApplicationModel.
        :type: bool
        """

        self._auto_delete_exceeded_scans = auto_delete_exceeded_scans

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in self.swagger_types.items():
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(CommonModelsASMModelsApplicationModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CommonModelsASMModelsApplicationModel):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CommonModelsASMModelsApplicationModel):
            return True

        return self.to_dict() != other.to_dict()



"""
    HCL AppScan on Cloud (v2)

    This API allows you to interact with the service. The API allows you to perform many of the operations available in the UI and more.</br>For authentication, use the relevant APIs in the Account section. A successful authentication response includes a bearer token for use in subsequent API calls. Pasting this token in the 'Access token' field above will automatically add the authorization header to any API call that requires a valid session.

    OpenAPI spec version: v2

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

from pyasoc.configuration import Configuration


class UserSiteCommonModelsImportIssueStatusModel:
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {"imported": "int", "updated": "int", "skipped": "int"}

    attribute_map = {"imported": "Imported", "updated": "Updated", "skipped": "Skipped"}

    def __init__(self, imported=None, updated=None, skipped=None, _configuration=None):
        """UserSiteCommonModelsImportIssueStatusModel - a model defined in Swagger"""
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._imported = None
        self._updated = None
        self._skipped = None
        self.discriminator = None

        if imported is not None:
            self.imported = imported
        if updated is not None:
            self.updated = updated
        if skipped is not None:
            self.skipped = skipped

    @property
    def imported(self):
        # type: () -> int
        """Gets the imported of this UserSiteCommonModelsImportIssueStatusModel.


        :return: The imported of this UserSiteCommonModelsImportIssueStatusModel.
        :rtype: int
        """
        return self._imported

    @imported.setter
    def imported(self, imported):
        """Sets the imported of this UserSiteCommonModelsImportIssueStatusModel.


        :param imported: The imported of this UserSiteCommonModelsImportIssueStatusModel.
        :type: int
        """

        self._imported = imported

    @property
    def updated(self):
        # type: () -> int
        """Gets the updated of this UserSiteCommonModelsImportIssueStatusModel.


        :return: The updated of this UserSiteCommonModelsImportIssueStatusModel.
        :rtype: int
        """
        return self._updated

    @updated.setter
    def updated(self, updated):
        """Sets the updated of this UserSiteCommonModelsImportIssueStatusModel.


        :param updated: The updated of this UserSiteCommonModelsImportIssueStatusModel.
        :type: int
        """

        self._updated = updated

    @property
    def skipped(self):
        # type: () -> int
        """Gets the skipped of this UserSiteCommonModelsImportIssueStatusModel.


        :return: The skipped of this UserSiteCommonModelsImportIssueStatusModel.
        :rtype: int
        """
        return self._skipped

    @skipped.setter
    def skipped(self, skipped):
        """Sets the skipped of this UserSiteCommonModelsImportIssueStatusModel.


        :param skipped: The skipped of this UserSiteCommonModelsImportIssueStatusModel.
        :type: int
        """

        self._skipped = skipped

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in self.swagger_types.items():
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(UserSiteCommonModelsImportIssueStatusModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UserSiteCommonModelsImportIssueStatusModel):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UserSiteCommonModelsImportIssueStatusModel):
            return True

        return self.to_dict() != other.to_dict()



"""
    HCL AppScan on Cloud (v2)

    This API allows you to interact with the service. The API allows you to perform many of the operations available in the UI and more.</br>For authentication, use the relevant APIs in the Account section. A successful authentication response includes a bearer token for use in subsequent API calls. Pasting this token in the 'Access token' field above will automatically add the authorization header to any API call that requires a valid session.

    OpenAPI spec version: v2

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

from pyasoc.configuration import Configuration


class AppScanSaaSModelsV2LicenseLibraryModel:
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "package_id": "str",
        "sha1": "str",
        "library_name": "str",
        "reference_type": "str",
        "reference": "str",
        "version": "str",
        "number_of_licenses": "int",
        "licence_id": "int",
        "risk_level": "str",
        "copyright_risk_score": "str",
        "patent_risk_score": "str",
        "linking": "str",
        "copy_left": "str",
        "royalty_free": "str",
        "url": "str",
        "license_name": "str",
        "first_found": "datetime",
        "last_found": "datetime",
        "package_location": "str",
    }

    attribute_map = {
        "package_id": "PackageId",
        "sha1": "Sha1",
        "library_name": "LibraryName",
        "reference_type": "ReferenceType",
        "reference": "Reference",
        "version": "Version",
        "number_of_licenses": "NumberOfLicenses",
        "licence_id": "LicenceId",
        "risk_level": "RiskLevel",
        "copyright_risk_score": "CopyrightRiskScore",
        "patent_risk_score": "PatentRiskScore",
        "linking": "Linking",
        "copy_left": "CopyLeft",
        "royalty_free": "RoyaltyFree",
        "url": "Url",
        "license_name": "LicenseName",
        "first_found": "FirstFound",
        "last_found": "LastFound",
        "package_location": "PackageLocation",
    }

    def __init__(
        self,
        package_id=None,
        sha1=None,
        library_name=None,
        reference_type=None,
        reference=None,
        version=None,
        number_of_licenses=None,
        licence_id=None,
        risk_level=None,
        copyright_risk_score=None,
        patent_risk_score=None,
        linking=None,
        copy_left=None,
        royalty_free=None,
        url=None,
        license_name=None,
        first_found=None,
        last_found=None,
        package_location=None,
        _configuration=None,
    ):
        """AppScanSaaSModelsV2LicenseLibraryModel - a model defined in Swagger"""
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._package_id = None
        self._sha1 = None
        self._library_name = None
        self._reference_type = None
        self._reference = None
        self._version = None
        self._number_of_licenses = None
        self._licence_id = None
        self._risk_level = None
        self._copyright_risk_score = None
        self._patent_risk_score = None
        self._linking = None
        self._copy_left = None
        self._royalty_free = None
        self._url = None
        self._license_name = None
        self._first_found = None
        self._last_found = None
        self._package_location = None
        self.discriminator = None

        if package_id is not None:
            self.package_id = package_id
        if sha1 is not None:
            self.sha1 = sha1
        if library_name is not None:
            self.library_name = library_name
        if reference_type is not None:
            self.reference_type = reference_type
        if reference is not None:
            self.reference = reference
        if version is not None:
            self.version = version
        if number_of_licenses is not None:
            self.number_of_licenses = number_of_licenses
        if licence_id is not None:
            self.licence_id = licence_id
        if risk_level is not None:
            self.risk_level = risk_level
        if copyright_risk_score is not None:
            self.copyright_risk_score = copyright_risk_score
        if patent_risk_score is not None:
            self.patent_risk_score = patent_risk_score
        if linking is not None:
            self.linking = linking
        if copy_left is not None:
            self.copy_left = copy_left
        if royalty_free is not None:
            self.royalty_free = royalty_free
        if url is not None:
            self.url = url
        if license_name is not None:
            self.license_name = license_name
        if first_found is not None:
            self.first_found = first_found
        if last_found is not None:
            self.last_found = last_found
        if package_location is not None:
            self.package_location = package_location

    @property
    def package_id(self):
        # type: () -> str
        """Gets the package_id of this AppScanSaaSModelsV2LicenseLibraryModel.


        :return: The package_id of this AppScanSaaSModelsV2LicenseLibraryModel.
        :rtype: str
        """
        return self._package_id

    @package_id.setter
    def package_id(self, package_id):
        """Sets the package_id of this AppScanSaaSModelsV2LicenseLibraryModel.


        :param package_id: The package_id of this AppScanSaaSModelsV2LicenseLibraryModel.
        :type: str
        """

        self._package_id = package_id

    @property
    def sha1(self):
        # type: () -> str
        """Gets the sha1 of this AppScanSaaSModelsV2LicenseLibraryModel.


        :return: The sha1 of this AppScanSaaSModelsV2LicenseLibraryModel.
        :rtype: str
        """
        return self._sha1

    @sha1.setter
    def sha1(self, sha1):
        """Sets the sha1 of this AppScanSaaSModelsV2LicenseLibraryModel.


        :param sha1: The sha1 of this AppScanSaaSModelsV2LicenseLibraryModel.
        :type: str
        """

        self._sha1 = sha1

    @property
    def library_name(self):
        # type: () -> str
        """Gets the library_name of this AppScanSaaSModelsV2LicenseLibraryModel.


        :return: The library_name of this AppScanSaaSModelsV2LicenseLibraryModel.
        :rtype: str
        """
        return self._library_name

    @library_name.setter
    def library_name(self, library_name):
        """Sets the library_name of this AppScanSaaSModelsV2LicenseLibraryModel.


        :param library_name: The library_name of this AppScanSaaSModelsV2LicenseLibraryModel.
        :type: str
        """

        self._library_name = library_name

    @property
    def reference_type(self):
        # type: () -> str
        """Gets the reference_type of this AppScanSaaSModelsV2LicenseLibraryModel.


        :return: The reference_type of this AppScanSaaSModelsV2LicenseLibraryModel.
        :rtype: str
        """
        return self._reference_type

    @reference_type.setter
    def reference_type(self, reference_type):
        """Sets the reference_type of this AppScanSaaSModelsV2LicenseLibraryModel.


        :param reference_type: The reference_type of this AppScanSaaSModelsV2LicenseLibraryModel.
        :type: str
        """
        allowed_values = [
            "Undefined",
            "ProjectHome",
            "POM",
            "NugetPkg",
            "PyPI",
            "NPM",
            "Bower",
            "RubyGems",
            "RPM",
            "Debian",
            "ArchLinux",
            "Alpine",
            "EclipseOSGIBundle",
            "GitHubRepository",
            "CDNJS",
            "DotNet",
            "HostFile",
            "LicenseFile",
            "ReadmeFile",
            "BuildConfigFile",
            "MsnByUser",
            "Other",
        ]
        if self._configuration.client_side_validation and reference_type not in allowed_values:
            raise ValueError(
                "Invalid value for `reference_type` ({}), must be one of {}".format(
                    reference_type, allowed_values
                )
            )

        self._reference_type = reference_type

    @property
    def reference(self):
        # type: () -> str
        """Gets the reference of this AppScanSaaSModelsV2LicenseLibraryModel.


        :return: The reference of this AppScanSaaSModelsV2LicenseLibraryModel.
        :rtype: str
        """
        return self._reference

    @reference.setter
    def reference(self, reference):
        """Sets the reference of this AppScanSaaSModelsV2LicenseLibraryModel.


        :param reference: The reference of this AppScanSaaSModelsV2LicenseLibraryModel.
        :type: str
        """

        self._reference = reference

    @property
    def version(self):
        # type: () -> str
        """Gets the version of this AppScanSaaSModelsV2LicenseLibraryModel.


        :return: The version of this AppScanSaaSModelsV2LicenseLibraryModel.
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this AppScanSaaSModelsV2LicenseLibraryModel.


        :param version: The version of this AppScanSaaSModelsV2LicenseLibraryModel.
        :type: str
        """

        self._version = version

    @property
    def number_of_licenses(self):
        # type: () -> int
        """Gets the number_of_licenses of this AppScanSaaSModelsV2LicenseLibraryModel.


        :return: The number_of_licenses of this AppScanSaaSModelsV2LicenseLibraryModel.
        :rtype: int
        """
        return self._number_of_licenses

    @number_of_licenses.setter
    def number_of_licenses(self, number_of_licenses):
        """Sets the number_of_licenses of this AppScanSaaSModelsV2LicenseLibraryModel.


        :param number_of_licenses: The number_of_licenses of this AppScanSaaSModelsV2LicenseLibraryModel.
        :type: int
        """

        self._number_of_licenses = number_of_licenses

    @property
    def licence_id(self):
        # type: () -> int
        """Gets the licence_id of this AppScanSaaSModelsV2LicenseLibraryModel.


        :return: The licence_id of this AppScanSaaSModelsV2LicenseLibraryModel.
        :rtype: int
        """
        return self._licence_id

    @licence_id.setter
    def licence_id(self, licence_id):
        """Sets the licence_id of this AppScanSaaSModelsV2LicenseLibraryModel.


        :param licence_id: The licence_id of this AppScanSaaSModelsV2LicenseLibraryModel.
        :type: int
        """

        self._licence_id = licence_id

    @property
    def risk_level(self):
        # type: () -> str
        """Gets the risk_level of this AppScanSaaSModelsV2LicenseLibraryModel.


        :return: The risk_level of this AppScanSaaSModelsV2LicenseLibraryModel.
        :rtype: str
        """
        return self._risk_level

    @risk_level.setter
    def risk_level(self, risk_level):
        """Sets the risk_level of this AppScanSaaSModelsV2LicenseLibraryModel.


        :param risk_level: The risk_level of this AppScanSaaSModelsV2LicenseLibraryModel.
        :type: str
        """
        allowed_values = ["Undefined", "Unknown", "Low", "Medium", "High"]
        if self._configuration.client_side_validation and risk_level not in allowed_values:
            raise ValueError(
                "Invalid value for `risk_level` ({}), must be one of {}".format(
                    risk_level, allowed_values
                )
            )

        self._risk_level = risk_level

    @property
    def copyright_risk_score(self):
        # type: () -> str
        """Gets the copyright_risk_score of this AppScanSaaSModelsV2LicenseLibraryModel.


        :return: The copyright_risk_score of this AppScanSaaSModelsV2LicenseLibraryModel.
        :rtype: str
        """
        return self._copyright_risk_score

    @copyright_risk_score.setter
    def copyright_risk_score(self, copyright_risk_score):
        """Sets the copyright_risk_score of this AppScanSaaSModelsV2LicenseLibraryModel.


        :param copyright_risk_score: The copyright_risk_score of this AppScanSaaSModelsV2LicenseLibraryModel.
        :type: str
        """
        allowed_values = [
            "Undefined",
            "One",
            "Two",
            "Three",
            "Four",
            "Five",
            "Six",
            "Seven",
        ]
        if (
            self._configuration.client_side_validation
            and copyright_risk_score not in allowed_values
        ):
            raise ValueError(
                "Invalid value for `copyright_risk_score` ({}), must be one of {}".format(
                    copyright_risk_score, allowed_values
                )
            )

        self._copyright_risk_score = copyright_risk_score

    @property
    def patent_risk_score(self):
        # type: () -> str
        """Gets the patent_risk_score of this AppScanSaaSModelsV2LicenseLibraryModel.


        :return: The patent_risk_score of this AppScanSaaSModelsV2LicenseLibraryModel.
        :rtype: str
        """
        return self._patent_risk_score

    @patent_risk_score.setter
    def patent_risk_score(self, patent_risk_score):
        """Sets the patent_risk_score of this AppScanSaaSModelsV2LicenseLibraryModel.


        :param patent_risk_score: The patent_risk_score of this AppScanSaaSModelsV2LicenseLibraryModel.
        :type: str
        """
        allowed_values = ["Undefined", "One", "Two", "Three", "Four"]
        if self._configuration.client_side_validation and patent_risk_score not in allowed_values:
            raise ValueError(
                "Invalid value for `patent_risk_score` ({}), must be one of {}".format(
                    patent_risk_score, allowed_values
                )
            )

        self._patent_risk_score = patent_risk_score

    @property
    def linking(self):
        # type: () -> str
        """Gets the linking of this AppScanSaaSModelsV2LicenseLibraryModel.


        :return: The linking of this AppScanSaaSModelsV2LicenseLibraryModel.
        :rtype: str
        """
        return self._linking

    @linking.setter
    def linking(self, linking):
        """Sets the linking of this AppScanSaaSModelsV2LicenseLibraryModel.


        :param linking: The linking of this AppScanSaaSModelsV2LicenseLibraryModel.
        :type: str
        """
        allowed_values = ["Undefined", "Viral", "Non_Viral", "Dynamic"]
        if self._configuration.client_side_validation and linking not in allowed_values:
            raise ValueError(
                "Invalid value for `linking` ({}), must be one of {}".format(
                    linking, allowed_values
                )
            )

        self._linking = linking

    @property
    def copy_left(self):
        # type: () -> str
        """Gets the copy_left of this AppScanSaaSModelsV2LicenseLibraryModel.


        :return: The copy_left of this AppScanSaaSModelsV2LicenseLibraryModel.
        :rtype: str
        """
        return self._copy_left

    @copy_left.setter
    def copy_left(self, copy_left):
        """Sets the copy_left of this AppScanSaaSModelsV2LicenseLibraryModel.


        :param copy_left: The copy_left of this AppScanSaaSModelsV2LicenseLibraryModel.
        :type: str
        """
        allowed_values = ["Undefined", "No", "Partial", "Full"]
        if self._configuration.client_side_validation and copy_left not in allowed_values:
            raise ValueError(
                "Invalid value for `copy_left` ({}), must be one of {}".format(
                    copy_left, allowed_values
                )
            )

        self._copy_left = copy_left

    @property
    def royalty_free(self):
        # type: () -> str
        """Gets the royalty_free of this AppScanSaaSModelsV2LicenseLibraryModel.


        :return: The royalty_free of this AppScanSaaSModelsV2LicenseLibraryModel.
        :rtype: str
        """
        return self._royalty_free

    @royalty_free.setter
    def royalty_free(self, royalty_free):
        """Sets the royalty_free of this AppScanSaaSModelsV2LicenseLibraryModel.


        :param royalty_free: The royalty_free of this AppScanSaaSModelsV2LicenseLibraryModel.
        :type: str
        """
        allowed_values = ["Yes", "Conditional", "No"]
        if self._configuration.client_side_validation and royalty_free not in allowed_values:
            raise ValueError(
                "Invalid value for `royalty_free` ({}), must be one of {}".format(
                    royalty_free, allowed_values
                )
            )

        self._royalty_free = royalty_free

    @property
    def url(self):
        # type: () -> str
        """Gets the url of this AppScanSaaSModelsV2LicenseLibraryModel.


        :return: The url of this AppScanSaaSModelsV2LicenseLibraryModel.
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this AppScanSaaSModelsV2LicenseLibraryModel.


        :param url: The url of this AppScanSaaSModelsV2LicenseLibraryModel.
        :type: str
        """

        self._url = url

    @property
    def license_name(self):
        # type: () -> str
        """Gets the license_name of this AppScanSaaSModelsV2LicenseLibraryModel.


        :return: The license_name of this AppScanSaaSModelsV2LicenseLibraryModel.
        :rtype: str
        """
        return self._license_name

    @license_name.setter
    def license_name(self, license_name):
        """Sets the license_name of this AppScanSaaSModelsV2LicenseLibraryModel.


        :param license_name: The license_name of this AppScanSaaSModelsV2LicenseLibraryModel.
        :type: str
        """

        self._license_name = license_name

    @property
    def first_found(self):
        # type: () -> datetime
        """Gets the first_found of this AppScanSaaSModelsV2LicenseLibraryModel.


        :return: The first_found of this AppScanSaaSModelsV2LicenseLibraryModel.
        :rtype: datetime
        """
        return self._first_found

    @first_found.setter
    def first_found(self, first_found):
        """Sets the first_found of this AppScanSaaSModelsV2LicenseLibraryModel.


        :param first_found: The first_found of this AppScanSaaSModelsV2LicenseLibraryModel.
        :type: datetime
        """

        self._first_found = first_found

    @property
    def last_found(self):
        # type: () -> datetime
        """Gets the last_found of this AppScanSaaSModelsV2LicenseLibraryModel.


        :return: The last_found of this AppScanSaaSModelsV2LicenseLibraryModel.
        :rtype: datetime
        """
        return self._last_found

    @last_found.setter
    def last_found(self, last_found):
        """Sets the last_found of this AppScanSaaSModelsV2LicenseLibraryModel.


        :param last_found: The last_found of this AppScanSaaSModelsV2LicenseLibraryModel.
        :type: datetime
        """

        self._last_found = last_found

    @property
    def package_location(self):
        # type: () -> str
        """Gets the package_location of this AppScanSaaSModelsV2LicenseLibraryModel.


        :return: The package_location of this AppScanSaaSModelsV2LicenseLibraryModel.
        :rtype: str
        """
        return self._package_location

    @package_location.setter
    def package_location(self, package_location):
        """Sets the package_location of this AppScanSaaSModelsV2LicenseLibraryModel.


        :param package_location: The package_location of this AppScanSaaSModelsV2LicenseLibraryModel.
        :type: str
        """

        self._package_location = package_location

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in self.swagger_types.items():
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(AppScanSaaSModelsV2LicenseLibraryModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AppScanSaaSModelsV2LicenseLibraryModel):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AppScanSaaSModelsV2LicenseLibraryModel):
            return True

        return self.to_dict() != other.to_dict()



"""
    HCL AppScan on Cloud (v2)

    This API allows you to interact with the service. The API allows you to perform many of the operations available in the UI and more.</br>For authentication, use the relevant APIs in the Account section. A successful authentication response includes a bearer token for use in subsequent API calls. Pasting this token in the 'Access token' field above will automatically add the authorization header to any API call that requires a valid session.

    OpenAPI spec version: v2

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

from pyasoc.configuration import Configuration


class UserSiteCommonModelsBasicUserInfo:
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "id": "str",
        "first_name": "str",
        "last_name": "str",
        "user_name": "str",
        "email": "str",
    }

    attribute_map = {
        "id": "Id",
        "first_name": "FirstName",
        "last_name": "LastName",
        "user_name": "UserName",
        "email": "Email",
    }

    def __init__(
        self,
        id=None,
        first_name=None,
        last_name=None,
        user_name=None,
        email=None,
        _configuration=None,
    ):
        """UserSiteCommonModelsBasicUserInfo - a model defined in Swagger"""
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._first_name = None
        self._last_name = None
        self._user_name = None
        self._email = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if first_name is not None:
            self.first_name = first_name
        if last_name is not None:
            self.last_name = last_name
        if user_name is not None:
            self.user_name = user_name
        if email is not None:
            self.email = email

    @property
    def id(self):
        # type: () -> str
        """Gets the id of this UserSiteCommonModelsBasicUserInfo.


        :return: The id of this UserSiteCommonModelsBasicUserInfo.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this UserSiteCommonModelsBasicUserInfo.


        :param id: The id of this UserSiteCommonModelsBasicUserInfo.
        :type: str
        """

        self._id = id

    @property
    def first_name(self):
        # type: () -> str
        """Gets the first_name of this UserSiteCommonModelsBasicUserInfo.


        :return: The first_name of this UserSiteCommonModelsBasicUserInfo.
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """Sets the first_name of this UserSiteCommonModelsBasicUserInfo.


        :param first_name: The first_name of this UserSiteCommonModelsBasicUserInfo.
        :type: str
        """

        self._first_name = first_name

    @property
    def last_name(self):
        # type: () -> str
        """Gets the last_name of this UserSiteCommonModelsBasicUserInfo.


        :return: The last_name of this UserSiteCommonModelsBasicUserInfo.
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """Sets the last_name of this UserSiteCommonModelsBasicUserInfo.


        :param last_name: The last_name of this UserSiteCommonModelsBasicUserInfo.
        :type: str
        """

        self._last_name = last_name

    @property
    def user_name(self):
        # type: () -> str
        """Gets the user_name of this UserSiteCommonModelsBasicUserInfo.


        :return: The user_name of this UserSiteCommonModelsBasicUserInfo.
        :rtype: str
        """
        return self._user_name

    @user_name.setter
    def user_name(self, user_name):
        """Sets the user_name of this UserSiteCommonModelsBasicUserInfo.


        :param user_name: The user_name of this UserSiteCommonModelsBasicUserInfo.
        :type: str
        """

        self._user_name = user_name

    @property
    def email(self):
        # type: () -> str
        """Gets the email of this UserSiteCommonModelsBasicUserInfo.


        :return: The email of this UserSiteCommonModelsBasicUserInfo.
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this UserSiteCommonModelsBasicUserInfo.


        :param email: The email of this UserSiteCommonModelsBasicUserInfo.
        :type: str
        """

        self._email = email

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in self.swagger_types.items():
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(UserSiteCommonModelsBasicUserInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UserSiteCommonModelsBasicUserInfo):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UserSiteCommonModelsBasicUserInfo):
            return True

        return self.to_dict() != other.to_dict()



# flake8: noqa
"""
    HCL AppScan on Cloud (v2)

    This API allows you to interact with the service. The API allows you to perform many of the operations available in the UI and more.</br>For authentication, use the relevant APIs in the Account section. A successful authentication response includes a bearer token for use in subsequent API calls. Pasting this token in the 'Access token' field above will automatically add the authorization header to any API call that requires a valid session.

    OpenAPI spec version: v2

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from .app_scan_saa_s_controllers_scans_controller_data import (
    AppScanSaaSControllersScansControllerData,
)
from .app_scan_saa_s_controllers_scans_controller_is_valid_url_response import (
    AppScanSaaSControllersScansControllerIsValidUrlResponse,
)
from .app_scan_saa_s_models_v2_business_unit_model import (
    AppScanSaaSModelsV2BusinessUnitModel,
)
from .app_scan_saa_s_models_v2_change import AppScanSaaSModelsV2Change
from .app_scan_saa_s_models_v2_dynamic_analyzer_scan import (
    AppScanSaaSModelsV2DynamicAnalyzerScan,
)
from .app_scan_saa_s_models_v2_dynamic_analyzer_scan_execution import (
    AppScanSaaSModelsV2DynamicAnalyzerScanExecution,
)
from .app_scan_saa_s_models_v2_error_response import AppScanSaaSModelsV2ErrorResponse
from .app_scan_saa_s_models_v2_explore_data_counters_model import (
    AppScanSaaSModelsV2ExploreDataCountersModel,
)
from .app_scan_saa_s_models_v2_iast_analyzer import AppScanSaaSModelsV2IASTAnalyzer
from .app_scan_saa_s_models_v2_iast_analyzer_scan_execution import (
    AppScanSaaSModelsV2IastAnalyzerScanExecution,
)
from .app_scan_saa_s_models_v2_issue_change_set import AppScanSaaSModelsV2IssueChangeSet
from .app_scan_saa_s_models_v2_license_library_model import (
    AppScanSaaSModelsV2LicenseLibraryModel,
)
from .app_scan_saa_s_models_v2_min_presence_data import (
    AppScanSaaSModelsV2MinPresenceData,
)
from .app_scan_saa_s_models_v2_min_scan_data import AppScanSaaSModelsV2MinScanData
from .app_scan_saa_s_models_v2_min_scan_execution import (
    AppScanSaaSModelsV2MinScanExecution,
)
from .app_scan_saa_s_models_v2_new_business_unit_model import (
    AppScanSaaSModelsV2NewBusinessUnitModel,
)
from .app_scan_saa_s_models_v2_new_webhook import AppScanSaaSModelsV2NewWebhook
from .app_scan_saa_s_models_v2_sca_analyzer_scan import (
    AppScanSaaSModelsV2ScaAnalyzerScan,
)
from .app_scan_saa_s_models_v2_sca_analyzer_scan_execution import (
    AppScanSaaSModelsV2ScaAnalyzerScanExecution,
)
from .app_scan_saa_s_models_v2_scan import AppScanSaaSModelsV2Scan
from .app_scan_saa_s_models_v2_scan1 import AppScanSaaSModelsV2Scan1
from .app_scan_saa_s_models_v2_scan_execution import AppScanSaaSModelsV2ScanExecution
from .app_scan_saa_s_models_v2_scan_execution1 import AppScanSaaSModelsV2ScanExecution1
from .app_scan_saa_s_models_v2_scan_execution_info import (
    AppScanSaaSModelsV2ScanExecutionInfo,
)
from .app_scan_saa_s_models_v2_scans_count_by_status import (
    AppScanSaaSModelsV2ScansCountByStatus,
)
from .app_scan_saa_s_models_v2_scans_count_by_technology import (
    AppScanSaaSModelsV2ScansCountByTechnology,
)
from .app_scan_saa_s_models_v2_scans_count_by_user import (
    AppScanSaaSModelsV2ScansCountByUser,
)
from .app_scan_saa_s_models_v2_static_analyzer_scan import (
    AppScanSaaSModelsV2StaticAnalyzerScan,
)
from .app_scan_saa_s_models_v2_static_analyzer_scan_execution import (
    AppScanSaaSModelsV2StaticAnalyzerScanExecution,
)
from .app_scan_saa_s_models_v2_update_business_unit_model import (
    AppScanSaaSModelsV2UpdateBusinessUnitModel,
)
from .app_scan_saa_s_models_v2_update_webhook import AppScanSaaSModelsV2UpdateWebhook
from .app_scan_saa_s_models_v2_webhook import AppScanSaaSModelsV2Webhook
from .app_scan_saa_s_models_v2_webhook_association import (
    AppScanSaaSModelsV2WebhookAssociation,
)
from .application_reset_model import ApplicationResetModel
from .common_models_asm_models_app_license import CommonModelsASMModelsAppLicense
from .common_models_asm_models_application_create_model import (
    CommonModelsASMModelsApplicationCreateModel,
)
from .common_models_asm_models_application_model import (
    CommonModelsASMModelsApplicationModel,
)
from .common_models_asm_models_application_update_model import (
    CommonModelsASMModelsApplicationUpdateModel,
)
from .common_models_asm_models_compliance_status import (
    CommonModelsASMModelsComplianceStatus,
)
from .common_models_domain_model import CommonModelsDomainModel
from .common_models_scx_account_scx_subscription import (
    CommonModelsSCXAccountSCXSubscription,
)
from .common_models_scx_account_scx_user_info import CommonModelsSCXAccountSCXUserInfo
from .common_models_scx_account_tenant_info import CommonModelsSCXAccountTenantInfo
from .common_models_update_domain_model import CommonModelsUpdateDomainModel
from .edit_policy import EditPolicy
from .import_app_result_model import ImportAppResultModel
from .microsoft_data_edm_annotations_i_edm_direct_value_annotations_manager import (
    MicrosoftDataEdmAnnotationsIEdmDirectValueAnnotationsManager,
)
from .microsoft_data_edm_annotations_i_edm_vocabulary_annotation import (
    MicrosoftDataEdmAnnotationsIEdmVocabularyAnnotation,
)
from .microsoft_data_edm_i_edm_model import MicrosoftDataEdmIEdmModel
from .microsoft_data_edm_i_edm_schema_element import MicrosoftDataEdmIEdmSchemaElement
from .microsoft_data_edm_i_edm_term import MicrosoftDataEdmIEdmTerm
from .microsoft_data_edm_i_edm_type import MicrosoftDataEdmIEdmType
from .microsoft_data_edm_i_edm_type_reference import MicrosoftDataEdmIEdmTypeReference
from .microsoft_data_edm_i_edm_vocabulary_annotatable import (
    MicrosoftDataEdmIEdmVocabularyAnnotatable,
)
from .microsoft_data_o_data_query_semantic_ast_filter_clause import (
    MicrosoftDataODataQuerySemanticAstFilterClause,
)
from .microsoft_data_o_data_query_semantic_ast_order_by_clause import (
    MicrosoftDataODataQuerySemanticAstOrderByClause,
)
from .microsoft_data_o_data_query_semantic_ast_range_variable import (
    MicrosoftDataODataQuerySemanticAstRangeVariable,
)
from .microsoft_data_o_data_query_semantic_ast_select_expand_clause import (
    MicrosoftDataODataQuerySemanticAstSelectExpandClause,
)
from .microsoft_data_o_data_query_semantic_ast_select_item import (
    MicrosoftDataODataQuerySemanticAstSelectItem,
)
from .microsoft_data_o_data_query_semantic_ast_single_value_node import (
    MicrosoftDataODataQuerySemanticAstSingleValueNode,
)
from .name_value_pair import NameValuePair
from .new_policy import NewPolicy
from .policy import Policy
from .policy_association import PolicyAssociation
from .policy_configuration import PolicyConfiguration
from .scan_manager_scan_models_postman_collection_files import (
    ScanManagerScanModelsPostmanCollectionFiles,
)
from .shared_components_configurations_dast_user_scan_configuration import (
    SharedComponentsConfigurationsDastUserScanConfiguration,
)
from .system_web_http_o_data_o_data_query_context import (
    SystemWebHttpODataODataQueryContext,
)
from .system_web_http_o_data_page_result_app_scan_saa_s_models_v2_business_unit_model import (
    SystemWebHttpODataPageResultAppScanSaaSModelsV2BusinessUnitModel,
)
from .system_web_http_o_data_page_result_app_scan_saa_s_models_v2_license_library_model import (
    SystemWebHttpODataPageResultAppScanSaaSModelsV2LicenseLibraryModel,
)
from .system_web_http_o_data_page_result_app_scan_saa_s_models_v2_min_scan_data import (
    SystemWebHttpODataPageResultAppScanSaaSModelsV2MinScanData,
)
from .system_web_http_o_data_page_result_app_scan_saa_s_models_v2_scan import (
    SystemWebHttpODataPageResultAppScanSaaSModelsV2Scan,
)
from .system_web_http_o_data_page_result_common_models_asm_models_application_model import (
    SystemWebHttpODataPageResultCommonModelsASMModelsApplicationModel,
)
from .system_web_http_o_data_page_result_common_models_domain_model import (
    SystemWebHttpODataPageResultCommonModelsDomainModel,
)
from .system_web_http_o_data_page_result_policy import (
    SystemWebHttpODataPageResultPolicy,
)
from .system_web_http_o_data_page_result_user_site_common_models_asset_group_model import (
    SystemWebHttpODataPageResultUserSiteCommonModelsAssetGroupModel,
)
from .system_web_http_o_data_page_result_user_site_common_models_fix_group import (
    SystemWebHttpODataPageResultUserSiteCommonModelsFixGroup,
)
from .system_web_http_o_data_page_result_user_site_common_models_user_model import (
    SystemWebHttpODataPageResultUserSiteCommonModelsUserModel,
)
from .system_web_http_o_data_page_result_utilities_issue_model import (
    SystemWebHttpODataPageResultUtilitiesIssueModel,
)
from .system_web_http_o_data_page_result_utilities_shared_models_correlation_group_model import (
    SystemWebHttpODataPageResultUtilitiesSharedModelsCorrelationGroupModel,
)
from .system_web_http_o_data_query_filter_query_option import (
    SystemWebHttpODataQueryFilterQueryOption,
)
from .system_web_http_o_data_query_inline_count_query_option import (
    SystemWebHttpODataQueryInlineCountQueryOption,
)
from .system_web_http_o_data_query_o_data_query_options_app_scan_saa_s_models_v2_business_unit_model import (
    SystemWebHttpODataQueryODataQueryOptionsAppScanSaaSModelsV2BusinessUnitModel,
)
from .system_web_http_o_data_query_o_data_query_options_app_scan_saa_s_models_v2_license_library_model import (
    SystemWebHttpODataQueryODataQueryOptionsAppScanSaaSModelsV2LicenseLibraryModel,
)
from .system_web_http_o_data_query_o_data_query_options_app_scan_saa_s_models_v2_min_scan_data import (
    SystemWebHttpODataQueryODataQueryOptionsAppScanSaaSModelsV2MinScanData,
)
from .system_web_http_o_data_query_o_data_query_options_app_scan_saa_s_models_v2_scan1 import (
    SystemWebHttpODataQueryODataQueryOptionsAppScanSaaSModelsV2Scan1,
)
from .system_web_http_o_data_query_o_data_query_options_common_models_asm_models_application_model import (
    SystemWebHttpODataQueryODataQueryOptionsCommonModelsASMModelsApplicationModel,
)
from .system_web_http_o_data_query_o_data_query_options_common_models_domain_model import (
    SystemWebHttpODataQueryODataQueryOptionsCommonModelsDomainModel,
)
from .system_web_http_o_data_query_o_data_query_options_policy import (
    SystemWebHttpODataQueryODataQueryOptionsPolicy,
)
from .system_web_http_o_data_query_o_data_query_options_user_site_common_models_asset_group_model import (
    SystemWebHttpODataQueryODataQueryOptionsUserSiteCommonModelsAssetGroupModel,
)
from .system_web_http_o_data_query_o_data_query_options_user_site_common_models_fix_group import (
    SystemWebHttpODataQueryODataQueryOptionsUserSiteCommonModelsFixGroup,
)
from .system_web_http_o_data_query_o_data_query_options_user_site_common_models_user_model import (
    SystemWebHttpODataQueryODataQueryOptionsUserSiteCommonModelsUserModel,
)
from .system_web_http_o_data_query_o_data_query_options_utilities_issue_model import (
    SystemWebHttpODataQueryODataQueryOptionsUtilitiesIssueModel,
)
from .system_web_http_o_data_query_o_data_query_options_utilities_shared_models_correlation_group_model import (
    SystemWebHttpODataQueryODataQueryOptionsUtilitiesSharedModelsCorrelationGroupModel,
)
from .system_web_http_o_data_query_o_data_raw_query_options import (
    SystemWebHttpODataQueryODataRawQueryOptions,
)
from .system_web_http_o_data_query_order_by_node import (
    SystemWebHttpODataQueryOrderByNode,
)
from .system_web_http_o_data_query_order_by_query_option import (
    SystemWebHttpODataQueryOrderByQueryOption,
)
from .system_web_http_o_data_query_select_expand_query_option import (
    SystemWebHttpODataQuerySelectExpandQueryOption,
)
from .system_web_http_o_data_query_skip_query_option import (
    SystemWebHttpODataQuerySkipQueryOption,
)
from .system_web_http_o_data_query_top_query_option import (
    SystemWebHttpODataQueryTopQueryOption,
)
from .system_web_http_o_data_query_validators_filter_query_validator import (
    SystemWebHttpODataQueryValidatorsFilterQueryValidator,
)
from .system_web_http_o_data_query_validators_o_data_query_validator import (
    SystemWebHttpODataQueryValidatorsODataQueryValidator,
)
from .system_web_http_o_data_query_validators_order_by_query_validator import (
    SystemWebHttpODataQueryValidatorsOrderByQueryValidator,
)
from .system_web_http_o_data_query_validators_select_expand_query_validator import (
    SystemWebHttpODataQueryValidatorsSelectExpandQueryValidator,
)
from .system_web_http_o_data_query_validators_skip_query_validator import (
    SystemWebHttpODataQueryValidatorsSkipQueryValidator,
)
from .system_web_http_o_data_query_validators_top_query_validator import (
    SystemWebHttpODataQueryValidatorsTopQueryValidator,
)
from .user_site_common_models_access_token_data import (
    UserSiteCommonModelsAccessTokenData,
)

# import models into model package
from .user_site_common_models_api_key import UserSiteCommonModelsApiKey
from .user_site_common_models_asset_group_model import (
    UserSiteCommonModelsAssetGroupModel,
)
from .user_site_common_models_asset_group_short_model import (
    UserSiteCommonModelsAssetGroupShortModel,
)
from .user_site_common_models_basic_user_info import UserSiteCommonModelsBasicUserInfo
from .user_site_common_models_comment_model import UserSiteCommonModelsCommentModel
from .user_site_common_models_comment_model_response import (
    UserSiteCommonModelsCommentModelResponse,
)
from .user_site_common_models_count_group_model import (
    UserSiteCommonModelsCountGroupModel,
)
from .user_site_common_models_count_model import UserSiteCommonModelsCountModel
from .user_site_common_models_explore_item import UserSiteCommonModelsExploreItem
from .user_site_common_models_fix_group import UserSiteCommonModelsFixGroup
from .user_site_common_models_fix_group_update import UserSiteCommonModelsFixGroupUpdate
from .user_site_common_models_group_count_element_model import (
    UserSiteCommonModelsGroupCountElementModel,
)
from .user_site_common_models_group_count_model import (
    UserSiteCommonModelsGroupCountModel,
)
from .user_site_common_models_import_issue_status_model import (
    UserSiteCommonModelsImportIssueStatusModel,
)
from .user_site_common_models_invite_model import UserSiteCommonModelsInviteModel
from .user_site_common_models_invite_result import UserSiteCommonModelsInviteResult
from .user_site_common_models_invite_users_model import (
    UserSiteCommonModelsInviteUsersModel,
)
from .user_site_common_models_issue_merge_model import (
    UserSiteCommonModelsIssueMergeModel,
)
from .user_site_common_models_issues_count_by_severity import (
    UserSiteCommonModelsIssuesCountBySeverity,
)
from .user_site_common_models_issues_count_by_status import (
    UserSiteCommonModelsIssuesCountByStatus,
)
from .user_site_common_models_issues_report_job import (
    UserSiteCommonModelsIssuesReportJob,
)
from .user_site_common_models_license_report_job import (
    UserSiteCommonModelsLicenseReportJob,
)
from .user_site_common_models_new_asset_group_model import (
    UserSiteCommonModelsNewAssetGroupModel,
)
from .user_site_common_models_new_dynamic_analyzer_scan import (
    UserSiteCommonModelsNewDynamicAnalyzerScan,
)
from .user_site_common_models_new_dynamic_analyzer_scan_by_template import (
    UserSiteCommonModelsNewDynamicAnalyzerScanByTemplate,
)
from .user_site_common_models_new_dynamic_analyzer_scan_with_files import (
    UserSiteCommonModelsNewDynamicAnalyzerScanWithFiles,
)
from .user_site_common_models_new_iast_analyzer_scan import (
    UserSiteCommonModelsNewIastAnalyzerScan,
)
from .user_site_common_models_new_iast_key import UserSiteCommonModelsNewIASTKey
from .user_site_common_models_new_key import UserSiteCommonModelsNewKey
from .user_site_common_models_new_presence import UserSiteCommonModelsNewPresence
from .user_site_common_models_new_role_model import UserSiteCommonModelsNewRoleModel
from .user_site_common_models_new_static_analyzer_scan import (
    UserSiteCommonModelsNewStaticAnalyzerScan,
)
from .user_site_common_models_presence import UserSiteCommonModelsPresence
from .user_site_common_models_regulation_report_job import (
    UserSiteCommonModelsRegulationReportJob,
)
from .user_site_common_models_report_status_model import (
    UserSiteCommonModelsReportStatusModel,
)
from .user_site_common_models_role_model import UserSiteCommonModelsRoleModel
from .user_site_common_models_scan_execute import UserSiteCommonModelsScanExecute
from .user_site_common_models_scan_results_model import (
    UserSiteCommonModelsScanResultsModel,
)
from .user_site_common_models_security_report_job import (
    UserSiteCommonModelsSecurityReportJob,
)
from .user_site_common_models_subscription_info_model import (
    UserSiteCommonModelsSubscriptionInfoModel,
)
from .user_site_common_models_triage_result import UserSiteCommonModelsTriageResult
from .user_site_common_models_update_dast_scan import UserSiteCommonModelsUpdateDastScan
from .user_site_common_models_update_iast_scan import UserSiteCommonModelsUpdateIastScan
from .user_site_common_models_update_presence import UserSiteCommonModelsUpdatePresence
from .user_site_common_models_update_user_model import (
    UserSiteCommonModelsUpdateUserModel,
)
from .user_site_common_models_upload_view_model import (
    UserSiteCommonModelsUploadViewModel,
)
from .user_site_common_models_user_grouping_model import (
    UserSiteCommonModelsUserGroupingModel,
)
from .user_site_common_models_user_model import UserSiteCommonModelsUserModel
from .user_site_common_models_users_count_model import (
    UserSiteCommonModelsUsersCountModel,
)
from .user_site_common_models_ver_and_hashes import UserSiteCommonModelsVerAndHashes
from .utilities_issue_model import UtilitiesIssueModel
from .utilities_shared_models_correlation_group_model import (
    UtilitiesSharedModelsCorrelationGroupModel,
)
from .utilities_structures_license_report_options import (
    UtilitiesStructuresLicenseReportOptions,
)
from .utilities_structures_regulation_report_options import (
    UtilitiesStructuresRegulationReportOptions,
)
from .utilities_structures_security_report_options import (
    UtilitiesStructuresSecurityReportOptions,
)
from .utilities_structures_tenant_info_model import UtilitiesStructuresTenantInfoModel
from .utilities_update_issue import UtilitiesUpdateIssue
